/*! normalize.css v2.1.3 | MIT License | git.io/normalize */
article, aside, details, figcaption, figure, footer, header, hgroup, main, nav, section, summary {
    display: block;
}
audio, canvas, video {
    display: inline-block;
}
audio:not([controls]) {
    display: none;
    height: 0;
}
[hidden], template {
    display: none;
}
html {
    font-family: sans-serif;
    -webkit-text-size-adjust: 100%;
    -ms-text-size-adjust: 100%}
body {
    margin: 0;
}
a {
    background: transparent;
}
a:focus {
    outline: thin dotted;
}
a:active, a:hover {
    outline: 0;
}
h1 {
    margin: .67em 0;
    font-size: 2em;
}
abbr[title] {
    border-bottom: 1px dotted;
}
b, strong {
    font-weight: bold;
}
dfn {
    font-style: italic;
}
hr {
    height: 0;
    -moz-box-sizing: content-box;
    box-sizing: content-box;
}
mark {
    color: #000;
    background: #ff0;
}
code, kbd, pre, samp {
    font-family: Hack, monospace, serif;
    font-size: 1em;
}
pre {
    white-space: pre-wrap;
}
q {
    quotes: "\201C" "\201D" "\2018" "\2019"}
small {
    font-size: 80%}
sub, sup {
    position: relative;
    font-size: 75%;
    line-height: 0;
    vertical-align: baseline;
}
sup {
    top: -0.5em;
}
sub {
    bottom: -0.25em;
}
img {
    border: 0;
}
svg:not(:root) {
    overflow: hidden;
}
figure {
    margin: 0;
}
fieldset {
    padding: .35em .625em .75em;
    margin: 0 2px;
    border: 1px solid #c0c0c0;
}
legend {
    padding: 0;
    border: 0;
}
button, input, select, textarea {
    margin: 0;
    font-family: inherit;
    font-size: 100%}
button, input {
    line-height: normal;
}
button, select {
    text-transform: none;
}
button, html input[type="button"], input[type="reset"], input[type="submit"] {
    cursor: pointer;
    -webkit-appearance: button;
}
button[disabled], html input[disabled] {
    cursor: default;
}
input[type="checkbox"], input[type="radio"] {
    padding: 0;
    box-sizing: border-box;
}
input[type="search"] {
    -webkit-box-sizing: content-box;
    -moz-box-sizing: content-box;
    box-sizing: content-box;
    -webkit-appearance: textfield;
}
input[type="search"]::-webkit-search-cancel-button, input[type="search"]::-webkit-search-decoration {
    -webkit-appearance: none;
}
button::-moz-focus-inner, input::-moz-focus-inner {
    padding: 0;
    border: 0;
}
textarea {
    overflow: auto;
    vertical-align: top;
}
table {
    border-collapse: collapse;
    border-spacing: 0;
}
@media print {
    * {
    color: #000!important;
    text-shadow: none!important;
    background: transparent!important;
    box-shadow: none!important;
}
a, a:visited {
    text-decoration: underline;
}
a[href]:after {
    content: " (" attr(href) ")"}
abbr[title]:after {
    content: " (" attr(title) ")"}
a[href^="javascript:"]:after, a[href^="#"]:after {
    content: ""}
pre, blockquote {
    border: 1px solid #999;
    page-break-inside: avoid;
}
thead {
    display: table-header-group;
}
tr, img {
    page-break-inside: avoid;
}
img {
    max-width: 100%!important;
}
@page {
    margin: 2cm .5cm;
}
p, h2, h3 {
    orphans: 3;
    widows: 3;
}
h2, h3 {
    page-break-after: avoid;
}
select {
    background: #fff!important;
}
.navbar {
    display: none;
}
.table td, .table th {
    background-color: #fff!important;
}
.btn>.caret, .dropup>.btn>.caret {
    border-top-color: #000!important;
}
.label {
    border: 1px solid #000;
}
.table {
    border-collapse: collapse!important;
}
.table-bordered th, .table-bordered td {
    border: 1px solid #ddd!important;
}
}*, *:before, *:after {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
}
html {
    font-size: 62.5%;
    -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
}
body {
    font-family: Merriweather, Georgia, serif;
    font-size: 14px;
    line-height: 1.428571429;
    color: #222;
    background-color: #fff;
}
input, button, select, textarea {
    font-family: inherit;
    font-size: inherit;
    line-height: inherit;
}
a {
    color: #008cba;
    text-decoration: none;
}
a:hover, a:focus {
    color: #00526e;
    text-decoration: underline;
}
a:focus {
    outline: thin dotted;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
}
img {
    vertical-align: middle;
}
.img-responsive {
    display: block;
    height: auto;
    max-width: 100%}
.img-rounded {
    border-radius: 0;
}
.img-thumbnail {
    display: inline-block;
    height: auto;
    max-width: 100%;
    padding: 4px;
    line-height: 1.428571429;
    background-color: #fff;
    border: 1px solid #ddd;
    border-radius: 0;
    -webkit-transition: all .2s ease-in-out;
    transition: all .2s ease-in-out;
}
.img-circle {
    border-radius: 50%}
hr {
    margin-top: 21px;
    margin-bottom: 21px;
    border: 0;
    border-top: 1px solid #ddd;
}
.sr-only {
    position: absolute;
    width: 1px;
    height: 1px;
    padding: 0;
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    border: 0;
}
h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6 {
    font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
    font-weight: 300;
    line-height: 1.1;
    color: inherit;
}
h1 small, h2 small, h3 small, h4 small, h5 small, h6 small, .h1 small, .h2 small, .h3 small, .h4 small, .h5 small, .h6 small, h1 .small, h2 .small, h3 .small, h4 .small, h5 .small, h6 .small, .h1 .small, .h2 .small, .h3 .small, .h4 .small, .h5 .small, .h6 .small {
    font-weight: normal;
    line-height: 1;
    color: #999;
}
h1, h2, h3 {
    margin-top: 21px;
    margin-bottom: 10.5px;
}
h1 small, h2 small, h3 small, h1 .small, h2 .small, h3 .small {
    font-size: 65%}
h4, h5, h6 {
    margin-top: 10.5px;
    margin-bottom: 10.5px;
}
h4 small, h5 small, h6 small, h4 .small, h5 .small, h6 .small {
    font-size: 75%}
h1, .h1 {
    font-size: 39px;
}
h2, .h2 {
    font-size: 32px;
}
h3, .h3 {
    font-size: 26px;
}
h4, .h4 {
    font-size: 19px;
}
h5, .h5 {
    font-size: 15px;
}
h6, .h6 {
    font-size: 13px;
}
p {
    margin: 0 0 10.5px;
}
.lead {
    margin-bottom: 21px;
    font-size: 17px;
    font-weight: 200;
    line-height: 1.4;
}
@media(min-width:768px) {
    .lead {
    font-size: 22.5px;
}
}small, .small {
    font-size: 85%}
cite {
    font-style: normal;
}
.text-muted {
    color: #999;
}
.text-primary {
    color: #008cba;
}
.text-primary:hover {
    color: #006687;
}
.text-warning {
    color: #e99002;
}
.text-warning:hover {
    color: #b67102;
}
.text-danger {
    color: #f04124;
}
.text-danger:hover {
    color: #d32a0e;
}
.text-success {
    color: #43ac6a;
}
.text-success:hover {
    color: #358753;
}
.text-info {
    color: #5bc0de;
}
.text-info:hover {
    color: #31b0d5;
}
.text-left {
    text-align: left;
}
.text-right {
    text-align: right;
}
.text-center {
    text-align: center;
}
.page-header {
    padding-bottom: 9.5px;
    margin: 42px 0 21px;
    border-bottom: 1px solid #ddd;
}
ul, ol {
    margin-top: 0;
    margin-bottom: 10.5px;
}
ul ul, ol ul, ul ol, ol ol {
    margin-bottom: 0;
}
.list-unstyled {
    padding-left: 0;
    list-style: none;
}
.list-inline {
    padding-left: 0;
    list-style: none;
}
.list-inline>li {
    display: inline-block;
    padding-right: 5px;
    padding-left: 5px;
}
.list-inline>li:first-child {
    padding-left: 0;
}
dl {
    margin-top: 0;
    margin-bottom: 21px;
}
dt, dd {
    line-height: 1.428571429;
}
dt {
    font-weight: bold;
}
dd {
    margin-left: 0;
}
@media(min-width:768px) {
    .dl-horizontal dt {
    float: left;
    width: 160px;
    overflow: hidden;
    clear: left;
    text-align: right;
    text-overflow: ellipsis;
    white-space: nowrap;
}
.dl-horizontal dd {
    margin-left: 180px;
}
.dl-horizontal dd:before, .dl-horizontal dd:after {
    display: table;
    content: " "}
.dl-horizontal dd:after {
    clear: both;
}
.dl-horizontal dd:before, .dl-horizontal dd:after {
    display: table;
    content: " "}
.dl-horizontal dd:after {
    clear: both;
}
.dl-horizontal dd:before, .dl-horizontal dd:after {
    display: table;
    content: " "}
.dl-horizontal dd:after {
    clear: both;
}
.dl-horizontal dd:before, .dl-horizontal dd:after {
    display: table;
    content: " "}
.dl-horizontal dd:after {
    clear: both;
}
.dl-horizontal dd:before, .dl-horizontal dd:after {
    display: table;
    content: " "}
.dl-horizontal dd:after {
    clear: both;
}
}abbr[title], abbr[data-original-title] {
    cursor: help;
    border-bottom: 1px dotted #999;
}
.initialism {
    font-size: 90%;
    text-transform: uppercase;
}
blockquote {
    padding: 10.5px 21px;
    margin: 0 0 21px;
    border-left: 5px solid #ddd;
}
blockquote p {
    font-size: 18.75px;
    font-weight: 300;
    line-height: 1.25;
}
blockquote p:last-child {
    margin-bottom: 0;
}
blockquote small, blockquote .small {
    display: block;
    line-height: 1.428571429;
    color: #6f6f6f;
}
blockquote small:before, blockquote .small:before {
    content: '\2014 \00A0'}
blockquote.pull-right {
    padding-right: 15px;
    padding-left: 0;
    border-right: 5px solid #ddd;
    border-left: 0;
}
blockquote.pull-right p, blockquote.pull-right small, blockquote.pull-right .small {
    text-align: right;
}
blockquote.pull-right small:before, blockquote.pull-right .small:before {
    content: ''}
blockquote.pull-right small:after, blockquote.pull-right .small:after {
    content: '\00A0 \2014'}
blockquote:before, blockquote:after {
    content: ""}
address {
    margin-bottom: 21px;
    font-style: normal;
    line-height: 1.428571429;
}
code, kbd, pre, samp {
    font-family: Hack, Menlo, Monaco, Consolas, "Courier New", monospace;
}
code {
    padding: 2px 4px;
    font-size: 90%;
    color: #c7254e;
    white-space: nowrap;
    background-color: #f9f2f4;
    border-radius: 0;
}
pre {
    display: block;
    padding: 10px;
    margin: 0 0 10.5px;
    font-size: 14px;
    line-height: 1.428571429;
    color: #333;
    word-break: break-all;
    word-wrap: break-word;
    background-color: #f5f5f5;
    border: 1px solid #ccc;
    border-radius: 0;
}
pre code {
    padding: 0;
    font-size: inherit;
    color: inherit;
    white-space: pre-wrap;
    background-color: transparent;
    border-radius: 0;
}
.pre-scrollable {
    max-height: 340px;
    overflow-y: scroll;
}
.container {
    padding-right: 15px;
    padding-left: 15px;
    margin-right: auto;
    margin-left: auto;
}
.container:before, .container:after {
    display: table;
    content: " "}
.container:after {
    clear: both;
}
.container:before, .container:after {
    display: table;
    content: " "}
.container:after {
    clear: both;
}
.container:before, .container:after {
    display: table;
    content: " "}
.container:after {
    clear: both;
}
.container:before, .container:after {
    display: table;
    content: " "}
.container:after {
    clear: both;
}
.container:before, .container:after {
    display: table;
    content: " "}
.container:after {
    clear: both;
}
@media(min-width:768px) {
    .container {
    width: 750px;
}
}@media(min-width:992px) {
    .container {
    width: 970px;
}
}@media(min-width:1200px) {
    .container {
    width: 1170px;
}
}.row {
    margin-right: -15px;
    margin-left: -15px;
}
.row:before, .row:after {
    display: table;
    content: " "}
.row:after {
    clear: both;
}
.row:before, .row:after {
    display: table;
    content: " "}
.row:after {
    clear: both;
}
.row:before, .row:after {
    display: table;
    content: " "}
.row:after {
    clear: both;
}
.row:before, .row:after {
    display: table;
    content: " "}
.row:after {
    clear: both;
}
.row:before, .row:after {
    display: table;
    content: " "}
.row:after {
    clear: both;
}
.col-xs-1, .col-sm-1, .col-md-1, .col-lg-1, .col-xs-2, .col-sm-2, .col-md-2, .col-lg-2, .col-xs-3, .col-sm-3, .col-md-3, .col-lg-3, .col-xs-4, .col-sm-4, .col-md-4, .col-lg-4, .col-xs-5, .col-sm-5, .col-md-5, .col-lg-5, .col-xs-6, .col-sm-6, .col-md-6, .col-lg-6, .col-xs-7, .col-sm-7, .col-md-7, .col-lg-7, .col-xs-8, .col-sm-8, .col-md-8, .col-lg-8, .col-xs-9, .col-sm-9, .col-md-9, .col-lg-9, .col-xs-10, .col-sm-10, .col-md-10, .col-lg-10, .col-xs-11, .col-sm-11, .col-md-11, .col-lg-11, .col-xs-12, .col-sm-12, .col-md-12, .col-lg-12 {
    position: relative;
    min-height: 1px;
    padding-right: 15px;
    padding-left: 15px;
}
.col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12 {
    float: left;
}
.col-xs-12 {
    width: 100%}
.col-xs-11 {
    width: 91.66666666666666%}
.col-xs-10 {
    width: 83.33333333333334%}
.col-xs-9 {
    width: 75%}
.col-xs-8 {
    width: 66.66666666666666%}
.col-xs-7 {
    width: 58.333333333333336%}
.col-xs-6 {
    width: 50%}
.col-xs-5 {
    width: 41.66666666666667%}
.col-xs-4 {
    width: 33.33333333333333%}
.col-xs-3 {
    width: 25%}
.col-xs-2 {
    width: 16.666666666666664%}
.col-xs-1 {
    width: 8.333333333333332%}
.col-xs-pull-12 {
    right: 100%}
.col-xs-pull-11 {
    right: 91.66666666666666%}
.col-xs-pull-10 {
    right: 83.33333333333334%}
.col-xs-pull-9 {
    right: 75%}
.col-xs-pull-8 {
    right: 66.66666666666666%}
.col-xs-pull-7 {
    right: 58.333333333333336%}
.col-xs-pull-6 {
    right: 50%}
.col-xs-pull-5 {
    right: 41.66666666666667%}
.col-xs-pull-4 {
    right: 33.33333333333333%}
.col-xs-pull-3 {
    right: 25%}
.col-xs-pull-2 {
    right: 16.666666666666664%}
.col-xs-pull-1 {
    right: 8.333333333333332%}
.col-xs-pull-0 {
    right: 0;
}
.col-xs-push-12 {
    left: 100%}
.col-xs-push-11 {
    left: 91.66666666666666%}
.col-xs-push-10 {
    left: 83.33333333333334%}
.col-xs-push-9 {
    left: 75%}
.col-xs-push-8 {
    left: 66.66666666666666%}
.col-xs-push-7 {
    left: 58.333333333333336%}
.col-xs-push-6 {
    left: 50%}
.col-xs-push-5 {
    left: 41.66666666666667%}
.col-xs-push-4 {
    left: 33.33333333333333%}
.col-xs-push-3 {
    left: 25%}
.col-xs-push-2 {
    left: 16.666666666666664%}
.col-xs-push-1 {
    left: 8.333333333333332%}
.col-xs-push-0 {
    left: 0;
}
.col-xs-offset-12 {
    margin-left: 100%}
.col-xs-offset-11 {
    margin-left: 91.66666666666666%}
.col-xs-offset-10 {
    margin-left: 83.33333333333334%}
.col-xs-offset-9 {
    margin-left: 75%}
.col-xs-offset-8 {
    margin-left: 66.66666666666666%}
.col-xs-offset-7 {
    margin-left: 58.333333333333336%}
.col-xs-offset-6 {
    margin-left: 50%}
.col-xs-offset-5 {
    margin-left: 41.66666666666667%}
.col-xs-offset-4 {
    margin-left: 33.33333333333333%}
.col-xs-offset-3 {
    margin-left: 25%}
.col-xs-offset-2 {
    margin-left: 16.666666666666664%}
.col-xs-offset-1 {
    margin-left: 8.333333333333332%}
.col-xs-offset-0 {
    margin-left: 0;
}
@media(min-width:768px) {
    .col-sm-1, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12 {
    float: left;
}
.col-sm-12 {
    width: 100%}
.col-sm-11 {
    width: 91.66666666666666%}
.col-sm-10 {
    width: 83.33333333333334%}
.col-sm-9 {
    width: 75%}
.col-sm-8 {
    width: 66.66666666666666%}
.col-sm-7 {
    width: 58.333333333333336%}
.col-sm-6 {
    width: 50%}
.col-sm-5 {
    width: 41.66666666666667%}
.col-sm-4 {
    width: 33.33333333333333%}
.col-sm-3 {
    width: 25%}
.col-sm-2 {
    width: 16.666666666666664%}
.col-sm-1 {
    width: 8.333333333333332%}
.col-sm-pull-12 {
    right: 100%}
.col-sm-pull-11 {
    right: 91.66666666666666%}
.col-sm-pull-10 {
    right: 83.33333333333334%}
.col-sm-pull-9 {
    right: 75%}
.col-sm-pull-8 {
    right: 66.66666666666666%}
.col-sm-pull-7 {
    right: 58.333333333333336%}
.col-sm-pull-6 {
    right: 50%}
.col-sm-pull-5 {
    right: 41.66666666666667%}
.col-sm-pull-4 {
    right: 33.33333333333333%}
.col-sm-pull-3 {
    right: 25%}
.col-sm-pull-2 {
    right: 16.666666666666664%}
.col-sm-pull-1 {
    right: 8.333333333333332%}
.col-sm-pull-0 {
    right: 0;
}
.col-sm-push-12 {
    left: 100%}
.col-sm-push-11 {
    left: 91.66666666666666%}
.col-sm-push-10 {
    left: 83.33333333333334%}
.col-sm-push-9 {
    left: 75%}
.col-sm-push-8 {
    left: 66.66666666666666%}
.col-sm-push-7 {
    left: 58.333333333333336%}
.col-sm-push-6 {
    left: 50%}
.col-sm-push-5 {
    left: 41.66666666666667%}
.col-sm-push-4 {
    left: 33.33333333333333%}
.col-sm-push-3 {
    left: 25%}
.col-sm-push-2 {
    left: 16.666666666666664%}
.col-sm-push-1 {
    left: 8.333333333333332%}
.col-sm-push-0 {
    left: 0;
}
.col-sm-offset-12 {
    margin-left: 100%}
.col-sm-offset-11 {
    margin-left: 91.66666666666666%}
.col-sm-offset-10 {
    margin-left: 83.33333333333334%}
.col-sm-offset-9 {
    margin-left: 75%}
.col-sm-offset-8 {
    margin-left: 66.66666666666666%}
.col-sm-offset-7 {
    margin-left: 58.333333333333336%}
.col-sm-offset-6 {
    margin-left: 50%}
.col-sm-offset-5 {
    margin-left: 41.66666666666667%}
.col-sm-offset-4 {
    margin-left: 33.33333333333333%}
.col-sm-offset-3 {
    margin-left: 25%}
.col-sm-offset-2 {
    margin-left: 16.666666666666664%}
.col-sm-offset-1 {
    margin-left: 8.333333333333332%}
.col-sm-offset-0 {
    margin-left: 0;
}
}@media(min-width:992px) {
    .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12 {
    float: left;
}
.col-md-12 {
    width: 100%}
.col-md-11 {
    width: 91.66666666666666%}
.col-md-10 {
    width: 83.33333333333334%}
.col-md-9 {
    width: 75%}
.col-md-8 {
    width: 66.66666666666666%}
.col-md-7 {
    width: 58.333333333333336%}
.col-md-6 {
    width: 50%}
.col-md-5 {
    width: 41.66666666666667%}
.col-md-4 {
    width: 33.33333333333333%}
.col-md-3 {
    width: 25%}
.col-md-2 {
    width: 16.666666666666664%}
.col-md-1 {
    width: 8.333333333333332%}
.col-md-pull-12 {
    right: 100%}
.col-md-pull-11 {
    right: 91.66666666666666%}
.col-md-pull-10 {
    right: 83.33333333333334%}
.col-md-pull-9 {
    right: 75%}
.col-md-pull-8 {
    right: 66.66666666666666%}
.col-md-pull-7 {
    right: 58.333333333333336%}
.col-md-pull-6 {
    right: 50%}
.col-md-pull-5 {
    right: 41.66666666666667%}
.col-md-pull-4 {
    right: 33.33333333333333%}
.col-md-pull-3 {
    right: 25%}
.col-md-pull-2 {
    right: 16.666666666666664%}
.col-md-pull-1 {
    right: 8.333333333333332%}
.col-md-pull-0 {
    right: 0;
}
.col-md-push-12 {
    left: 100%}
.col-md-push-11 {
    left: 91.66666666666666%}
.col-md-push-10 {
    left: 83.33333333333334%}
.col-md-push-9 {
    left: 75%}
.col-md-push-8 {
    left: 66.66666666666666%}
.col-md-push-7 {
    left: 58.333333333333336%}
.col-md-push-6 {
    left: 50%}
.col-md-push-5 {
    left: 41.66666666666667%}
.col-md-push-4 {
    left: 33.33333333333333%}
.col-md-push-3 {
    left: 25%}
.col-md-push-2 {
    left: 16.666666666666664%}
.col-md-push-1 {
    left: 8.333333333333332%}
.col-md-push-0 {
    left: 0;
}
.col-md-offset-12 {
    margin-left: 100%}
.col-md-offset-11 {
    margin-left: 91.66666666666666%}
.col-md-offset-10 {
    margin-left: 83.33333333333334%}
.col-md-offset-9 {
    margin-left: 75%}
.col-md-offset-8 {
    margin-left: 66.66666666666666%}
.col-md-offset-7 {
    margin-left: 58.333333333333336%}
.col-md-offset-6 {
    margin-left: 50%}
.col-md-offset-5 {
    margin-left: 41.66666666666667%}
.col-md-offset-4 {
    margin-left: 33.33333333333333%}
.col-md-offset-3 {
    margin-left: 25%}
.col-md-offset-2 {
    margin-left: 16.666666666666664%}
.col-md-offset-1 {
    margin-left: 8.333333333333332%}
.col-md-offset-0 {
    margin-left: 0;
}
}@media(min-width:1200px) {
    .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12 {
    float: left;
}
.col-lg-12 {
    width: 100%}
.col-lg-11 {
    width: 91.66666666666666%}
.col-lg-10 {
    width: 83.33333333333334%}
.col-lg-9 {
    width: 75%}
.col-lg-8 {
    width: 66.66666666666666%}
.col-lg-7 {
    width: 58.333333333333336%}
.col-lg-6 {
    width: 50%}
.col-lg-5 {
    width: 41.66666666666667%}
.col-lg-4 {
    width: 33.33333333333333%}
.col-lg-3 {
    width: 25%}
.col-lg-2 {
    width: 16.666666666666664%}
.col-lg-1 {
    width: 8.333333333333332%}
.col-lg-pull-12 {
    right: 100%}
.col-lg-pull-11 {
    right: 91.66666666666666%}
.col-lg-pull-10 {
    right: 83.33333333333334%}
.col-lg-pull-9 {
    right: 75%}
.col-lg-pull-8 {
    right: 66.66666666666666%}
.col-lg-pull-7 {
    right: 58.333333333333336%}
.col-lg-pull-6 {
    right: 50%}
.col-lg-pull-5 {
    right: 41.66666666666667%}
.col-lg-pull-4 {
    right: 33.33333333333333%}
.col-lg-pull-3 {
    right: 25%}
.col-lg-pull-2 {
    right: 16.666666666666664%}
.col-lg-pull-1 {
    right: 8.333333333333332%}
.col-lg-pull-0 {
    right: 0;
}
.col-lg-push-12 {
    left: 100%}
.col-lg-push-11 {
    left: 91.66666666666666%}
.col-lg-push-10 {
    left: 83.33333333333334%}
.col-lg-push-9 {
    left: 75%}
.col-lg-push-8 {
    left: 66.66666666666666%}
.col-lg-push-7 {
    left: 58.333333333333336%}
.col-lg-push-6 {
    left: 50%}
.col-lg-push-5 {
    left: 41.66666666666667%}
.col-lg-push-4 {
    left: 33.33333333333333%}
.col-lg-push-3 {
    left: 25%}
.col-lg-push-2 {
    left: 16.666666666666664%}
.col-lg-push-1 {
    left: 8.333333333333332%}
.col-lg-push-0 {
    left: 0;
}
.col-lg-offset-12 {
    margin-left: 100%}
.col-lg-offset-11 {
    margin-left: 91.66666666666666%}
.col-lg-offset-10 {
    margin-left: 83.33333333333334%}
.col-lg-offset-9 {
    margin-left: 75%}
.col-lg-offset-8 {
    margin-left: 66.66666666666666%}
.col-lg-offset-7 {
    margin-left: 58.333333333333336%}
.col-lg-offset-6 {
    margin-left: 50%}
.col-lg-offset-5 {
    margin-left: 41.66666666666667%}
.col-lg-offset-4 {
    margin-left: 33.33333333333333%}
.col-lg-offset-3 {
    margin-left: 25%}
.col-lg-offset-2 {
    margin-left: 16.666666666666664%}
.col-lg-offset-1 {
    margin-left: 8.333333333333332%}
.col-lg-offset-0 {
    margin-left: 0;
}
}table {
    max-width: 100%;
    background-color: transparent;
}
th {
    text-align: left;
}
.table {
    width: 100%;
    margin-bottom: 21px;
}
.table>thead>tr>th, .table>tbody>tr>th, .table>tfoot>tr>th, .table>thead>tr>td, .table>tbody>tr>td, .table>tfoot>tr>td {
    padding: 8px;
    line-height: 1.428571429;
    vertical-align: top;
    border-top: 1px solid #ddd;
}
.table>thead>tr>th {
    vertical-align: bottom;
    border-bottom: 2px solid #ddd;
}
.table>caption+thead>tr:first-child>th, .table>colgroup+thead>tr:first-child>th, .table>thead:first-child>tr:first-child>th, .table>caption+thead>tr:first-child>td, .table>colgroup+thead>tr:first-child>td, .table>thead:first-child>tr:first-child>td {
    border-top: 0;
}
.table>tbody+tbody {
    border-top: 2px solid #ddd;
}
.table .table {
    background-color: #fff;
}
.table-condensed>thead>tr>th, .table-condensed>tbody>tr>th, .table-condensed>tfoot>tr>th, .table-condensed>thead>tr>td, .table-condensed>tbody>tr>td, .table-condensed>tfoot>tr>td {
    padding: 5px;
}
.table-bordered {
    border: 1px solid #ddd;
}
.table-bordered>thead>tr>th, .table-bordered>tbody>tr>th, .table-bordered>tfoot>tr>th, .table-bordered>thead>tr>td, .table-bordered>tbody>tr>td, .table-bordered>tfoot>tr>td {
    border: 1px solid #ddd;
}
.table-bordered>thead>tr>th, .table-bordered>thead>tr>td {
    border-bottom-width: 2px;
}
.table-striped>tbody>tr:nth-child(odd)>td, .table-striped>tbody>tr:nth-child(odd)>th {
    background-color: #f9f9f9;
}
.table-hover>tbody>tr:hover>td, .table-hover>tbody>tr:hover>th {
    background-color: #f5f5f5;
}
table col[class*="col-"] {
    position: static;
    display: table-column;
    float: none;
}
table td[class*="col-"], table th[class*="col-"] {
    display: table-cell;
    float: none;
}
.table>thead>tr>.active, .table>tbody>tr>.active, .table>tfoot>tr>.active, .table>thead>.active>td, .table>tbody>.active>td, .table>tfoot>.active>td, .table>thead>.active>th, .table>tbody>.active>th, .table>tfoot>.active>th {
    background-color: #f5f5f5;
}
.table-hover>tbody>tr>.active:hover, .table-hover>tbody>.active:hover>td, .table-hover>tbody>.active:hover>th {
    background-color: #e8e8e8;
}
.table>thead>tr>.success, .table>tbody>tr>.success, .table>tfoot>tr>.success, .table>thead>.success>td, .table>tbody>.success>td, .table>tfoot>.success>td, .table>thead>.success>th, .table>tbody>.success>th, .table>tfoot>.success>th {
    background-color: #dff0d8;
}
.table-hover>tbody>tr>.success:hover, .table-hover>tbody>.success:hover>td, .table-hover>tbody>.success:hover>th {
    background-color: #d0e9c6;
}
.table>thead>tr>.danger, .table>tbody>tr>.danger, .table>tfoot>tr>.danger, .table>thead>.danger>td, .table>tbody>.danger>td, .table>tfoot>.danger>td, .table>thead>.danger>th, .table>tbody>.danger>th, .table>tfoot>.danger>th {
    background-color: #f2dede;
}
.table-hover>tbody>tr>.danger:hover, .table-hover>tbody>.danger:hover>td, .table-hover>tbody>.danger:hover>th {
    background-color: #ebcccc;
}
.table>thead>tr>.warning, .table>tbody>tr>.warning, .table>tfoot>tr>.warning, .table>thead>.warning>td, .table>tbody>.warning>td, .table>tfoot>.warning>td, .table>thead>.warning>th, .table>tbody>.warning>th, .table>tfoot>.warning>th {
    background-color: #fcf8e3;
}
.table-hover>tbody>tr>.warning:hover, .table-hover>tbody>.warning:hover>td, .table-hover>tbody>.warning:hover>th {
    background-color: #faf2cc;
}
@media(max-width:767px) {
    .table-responsive {
    width: 100%;
    margin-bottom: 15.75px;
    overflow-x: scroll;
    overflow-y: hidden;
    border: 1px solid #ddd;
    -ms-overflow-style: -ms-autohiding-scrollbar;
    -webkit-overflow-scrolling: touch;
}
.table-responsive>.table {
    margin-bottom: 0;
}
.table-responsive>.table>thead>tr>th, .table-responsive>.table>tbody>tr>th, .table-responsive>.table>tfoot>tr>th, .table-responsive>.table>thead>tr>td, .table-responsive>.table>tbody>tr>td, .table-responsive>.table>tfoot>tr>td {
    white-space: nowrap;
}
.table-responsive>.table-bordered {
    border: 0;
}
.table-responsive>.table-bordered>thead>tr>th:first-child, .table-responsive>.table-bordered>tbody>tr>th:first-child, .table-responsive>.table-bordered>tfoot>tr>th:first-child, .table-responsive>.table-bordered>thead>tr>td:first-child, .table-responsive>.table-bordered>tbody>tr>td:first-child, .table-responsive>.table-bordered>tfoot>tr>td:first-child {
    border-left: 0;
}
.table-responsive>.table-bordered>thead>tr>th:last-child, .table-responsive>.table-bordered>tbody>tr>th:last-child, .table-responsive>.table-bordered>tfoot>tr>th:last-child, .table-responsive>.table-bordered>thead>tr>td:last-child, .table-responsive>.table-bordered>tbody>tr>td:last-child, .table-responsive>.table-bordered>tfoot>tr>td:last-child {
    border-right: 0;
}
.table-responsive>.table-bordered>tbody>tr:last-child>th, .table-responsive>.table-bordered>tfoot>tr:last-child>th, .table-responsive>.table-bordered>tbody>tr:last-child>td, .table-responsive>.table-bordered>tfoot>tr:last-child>td {
    border-bottom: 0;
}
}fieldset {
    padding: 0;
    margin: 0;
    border: 0;
}
legend {
    display: block;
    width: 100%;
    padding: 0;
    margin-bottom: 21px;
    font-size: 22.5px;
    line-height: inherit;
    color: #333;
    border: 0;
    border-bottom: 1px solid #e5e5e5;
}
label {
    display: inline-block;
    margin-bottom: 5px;
    font-weight: bold;
}
input[type="search"] {
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
}
input[type="radio"], input[type="checkbox"] {
    margin: 4px 0 0;
    margin-top: 1px \9;
    line-height: normal;
}
input[type="file"] {
    display: block;
}
select[multiple], select[size] {
    height: auto;
}
select optgroup {
    font-family: inherit;
    font-size: inherit;
    font-style: inherit;
}
input[type="file"]:focus, input[type="radio"]:focus, input[type="checkbox"]:focus {
    outline: thin dotted;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
}
input[type="number"]::-webkit-outer-spin-button, input[type="number"]::-webkit-inner-spin-button {
    height: auto;
}
output {
    display: block;
    padding-top: 7px;
    font-size: 15px;
    line-height: 1.428571429;
    color: #6f6f6f;
    vertical-align: middle;
}
.form-control {
    display: block;
    width: 100%;
    height: 35px;
    padding: 6px 12px;
    font-size: 15px;
    line-height: 1.428571429;
    color: #6f6f6f;
    vertical-align: middle;
    background-color: #fff;
    background-image: none;
    border: 1px solid #ccc;
    border-radius: 0;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    -webkit-transition: border-color ease-in-out .15s, box-shadow ease-in-out .15s;
    transition: border-color ease-in-out .15s, box-shadow ease-in-out .15s;
}
.form-control:focus {
    border-color: #66afe9;
    outline: 0;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
}
.form-control:-moz-placeholder {
    color: #999;
}
.form-control::-moz-placeholder {
    color: #999;
    opacity: 1;
}
.form-control:-ms-input-placeholder {
    color: #999;
}
.form-control::-webkit-input-placeholder {
    color: #999;
}
.form-control[disabled], .form-control[readonly], fieldset[disabled] .form-control {
    cursor: not-allowed;
    background-color: #eee;
}
textarea.form-control {
    height: auto;
}
.form-group {
    margin-bottom: 15px;
}
.radio, .checkbox {
    display: block;
    min-height: 21px;
    padding-left: 20px;
    margin-top: 10px;
    margin-bottom: 10px;
    vertical-align: middle;
}
.radio label, .checkbox label {
    display: inline;
    margin-bottom: 0;
    font-weight: normal;
    cursor: pointer;
}
.radio input[type="radio"], .radio-inline input[type="radio"], .checkbox input[type="checkbox"], .checkbox-inline input[type="checkbox"] {
    float: left;
    margin-left: -20px;
}
.radio+.radio, .checkbox+.checkbox {
    margin-top: -5px;
}
.radio-inline, .checkbox-inline {
    display: inline-block;
    padding-left: 20px;
    margin-bottom: 0;
    font-weight: normal;
    vertical-align: middle;
    cursor: pointer;
}
.radio-inline+.radio-inline, .checkbox-inline+.checkbox-inline {
    margin-top: 0;
    margin-left: 10px;
}
input[type="radio"][disabled], input[type="checkbox"][disabled], .radio[disabled], .radio-inline[disabled], .checkbox[disabled], .checkbox-inline[disabled], fieldset[disabled] input[type="radio"], fieldset[disabled] input[type="checkbox"], fieldset[disabled] .radio, fieldset[disabled] .radio-inline, fieldset[disabled] .checkbox, fieldset[disabled] .checkbox-inline {
    cursor: not-allowed;
}
.input-sm {
    height: 30px;
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 0;
}
select.input-sm {
    height: 30px;
    line-height: 30px;
}
textarea.input-sm {
    height: auto;
}
.input-lg {
    height: 48px;
    padding: 10px 16px;
    font-size: 19px;
    line-height: 1.33;
    border-radius: 0;
}
select.input-lg {
    height: 48px;
    line-height: 48px;
}
textarea.input-lg {
    height: auto;
}
.has-warning .help-block, .has-warning .control-label, .has-warning .radio, .has-warning .checkbox, .has-warning .radio-inline, .has-warning .checkbox-inline {
    color: #e99002;
}
.has-warning .form-control {
    border-color: #e99002;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.has-warning .form-control:focus {
    border-color: #b67102;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #febc53;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #febc53;
}
.has-warning .input-group-addon {
    color: #e99002;
    background-color: #fcf8e3;
    border-color: #e99002;
}
.has-error .help-block, .has-error .control-label, .has-error .radio, .has-error .checkbox, .has-error .radio-inline, .has-error .checkbox-inline {
    color: #f04124;
}
.has-error .form-control {
    border-color: #f04124;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.has-error .form-control:focus {
    border-color: #d32a0e;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #f79483;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #f79483;
}
.has-error .input-group-addon {
    color: #f04124;
    background-color: #f2dede;
    border-color: #f04124;
}
.has-success .help-block, .has-success .control-label, .has-success .radio, .has-success .checkbox, .has-success .radio-inline, .has-success .checkbox-inline {
    color: #43ac6a;
}
.has-success .form-control {
    border-color: #43ac6a;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.has-success .form-control:focus {
    border-color: #358753;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #85d0a1;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #85d0a1;
}
.has-success .input-group-addon {
    color: #43ac6a;
    background-color: #dff0d8;
    border-color: #43ac6a;
}
.form-control-static {
    margin-bottom: 0;
}
.help-block {
    display: block;
    margin-top: 5px;
    margin-bottom: 10px;
    color: #626262;
}
@media(min-width:768px) {
    .form-inline .form-group {
    display: inline-block;
    margin-bottom: 0;
    vertical-align: middle;
}
.form-inline .form-control {
    display: inline-block;
}
.form-inline select.form-control {
    width: auto;
}
.form-inline .radio, .form-inline .checkbox {
    display: inline-block;
    padding-left: 0;
    margin-top: 0;
    margin-bottom: 0;
}
.form-inline .radio input[type="radio"], .form-inline .checkbox input[type="checkbox"] {
    float: none;
    margin-left: 0;
}
}.form-horizontal .control-label, .form-horizontal .radio, .form-horizontal .checkbox, .form-horizontal .radio-inline, .form-horizontal .checkbox-inline {
    padding-top: 7px;
    margin-top: 0;
    margin-bottom: 0;
}
.form-horizontal .radio, .form-horizontal .checkbox {
    min-height: 28px;
}
.form-horizontal .form-group {
    margin-right: -15px;
    margin-left: -15px;
}
.form-horizontal .form-group:before, .form-horizontal .form-group:after {
    display: table;
    content: " "}
.form-horizontal .form-group:after {
    clear: both;
}
.form-horizontal .form-group:before, .form-horizontal .form-group:after {
    display: table;
    content: " "}
.form-horizontal .form-group:after {
    clear: both;
}
.form-horizontal .form-group:before, .form-horizontal .form-group:after {
    display: table;
    content: " "}
.form-horizontal .form-group:after {
    clear: both;
}
.form-horizontal .form-group:before, .form-horizontal .form-group:after {
    display: table;
    content: " "}
.form-horizontal .form-group:after {
    clear: both;
}
.form-horizontal .form-group:before, .form-horizontal .form-group:after {
    display: table;
    content: " "}
.form-horizontal .form-group:after {
    clear: both;
}
.form-horizontal .form-control-static {
    padding-top: 7px;
}
@media(min-width:768px) {
    .form-horizontal .control-label {
    text-align: right;
}
}.btn {
    display: inline-block;
    padding: 6px 12px;
    margin-bottom: 0;
    font-size: 15px;
    font-weight: normal;
    line-height: 1.428571429;
    text-align: center;
    white-space: nowrap;
    vertical-align: middle;
    cursor: pointer;
    background-image: none;
    border: 1px solid transparent;
    border-radius: 0;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    -o-user-select: none;
    user-select: none;
}
.btn:focus {
    outline: thin dotted;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
}
.btn:hover, .btn:focus {
    color: #333;
    text-decoration: none;
}
.btn:active, .btn.active {
    background-image: none;
    outline: 0;
    -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
    box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
.btn.disabled, .btn[disabled], fieldset[disabled] .btn {
    pointer-events: none;
    cursor: not-allowed;
    opacity: .65;
    filter: alpha(opacity=65);
    -webkit-box-shadow: none;
    box-shadow: none;
}
.btn-default {
    color: #333;
    background-color: #e7e7e7;
    border-color: #dadada;
}
.btn-default:hover, .btn-default:focus, .btn-default:active, .btn-default.active, .open .dropdown-toggle.btn-default {
    color: #333;
    background-color: #d3d3d3;
    border-color: #bbb;
}
.btn-default:active, .btn-default.active, .open .dropdown-toggle.btn-default {
    background-image: none;
}
.btn-default.disabled, .btn-default[disabled], fieldset[disabled] .btn-default, .btn-default.disabled:hover, .btn-default[disabled]:hover, fieldset[disabled] .btn-default:hover, .btn-default.disabled:focus, .btn-default[disabled]:focus, fieldset[disabled] .btn-default:focus, .btn-default.disabled:active, .btn-default[disabled]:active, fieldset[disabled] .btn-default:active, .btn-default.disabled.active, .btn-default[disabled].active, fieldset[disabled] .btn-default.active {
    background-color: #e7e7e7;
    border-color: #dadada;
}
.btn-default .badge {
    color: #e7e7e7;
    background-color: #fff;
}
.btn-primary {
    color: #fff;
    background-color: #008cba;
    border-color: #0079a1;
}
.btn-primary:hover, .btn-primary:focus, .btn-primary:active, .btn-primary.active, .open .dropdown-toggle.btn-primary {
    color: #fff;
    background-color: #006d91;
    border-color: #004b63;
}
.btn-primary:active, .btn-primary.active, .open .dropdown-toggle.btn-primary {
    background-image: none;
}
.btn-primary.disabled, .btn-primary[disabled], fieldset[disabled] .btn-primary, .btn-primary.disabled:hover, .btn-primary[disabled]:hover, fieldset[disabled] .btn-primary:hover, .btn-primary.disabled:focus, .btn-primary[disabled]:focus, fieldset[disabled] .btn-primary:focus, .btn-primary.disabled:active, .btn-primary[disabled]:active, fieldset[disabled] .btn-primary:active, .btn-primary.disabled.active, .btn-primary[disabled].active, fieldset[disabled] .btn-primary.active {
    background-color: #008cba;
    border-color: #0079a1;
}
.btn-primary .badge {
    color: #008cba;
    background-color: #fff;
}
.btn-warning {
    color: #fff;
    background-color: #e99002;
    border-color: #d08002;
}
.btn-warning:hover, .btn-warning:focus, .btn-warning:active, .btn-warning.active, .open .dropdown-toggle.btn-warning {
    color: #fff;
    background-color: #c17702;
    border-color: #935b01;
}
.btn-warning:active, .btn-warning.active, .open .dropdown-toggle.btn-warning {
    background-image: none;
}
.btn-warning.disabled, .btn-warning[disabled], fieldset[disabled] .btn-warning, .btn-warning.disabled:hover, .btn-warning[disabled]:hover, fieldset[disabled] .btn-warning:hover, .btn-warning.disabled:focus, .btn-warning[disabled]:focus, fieldset[disabled] .btn-warning:focus, .btn-warning.disabled:active, .btn-warning[disabled]:active, fieldset[disabled] .btn-warning:active, .btn-warning.disabled.active, .btn-warning[disabled].active, fieldset[disabled] .btn-warning.active {
    background-color: #e99002;
    border-color: #d08002;
}
.btn-warning .badge {
    color: #e99002;
    background-color: #fff;
}
.btn-danger {
    color: #fff;
    background-color: #f04124;
    border-color: #ea2f10;
}
.btn-danger:hover, .btn-danger:focus, .btn-danger:active, .btn-danger.active, .open .dropdown-toggle.btn-danger {
    color: #fff;
    background-color: #dc2c0f;
    border-color: #b1240c;
}
.btn-danger:active, .btn-danger.active, .open .dropdown-toggle.btn-danger {
    background-image: none;
}
.btn-danger.disabled, .btn-danger[disabled], fieldset[disabled] .btn-danger, .btn-danger.disabled:hover, .btn-danger[disabled]:hover, fieldset[disabled] .btn-danger:hover, .btn-danger.disabled:focus, .btn-danger[disabled]:focus, fieldset[disabled] .btn-danger:focus, .btn-danger.disabled:active, .btn-danger[disabled]:active, fieldset[disabled] .btn-danger:active, .btn-danger.disabled.active, .btn-danger[disabled].active, fieldset[disabled] .btn-danger.active {
    background-color: #f04124;
    border-color: #ea2f10;
}
.btn-danger .badge {
    color: #f04124;
    background-color: #fff;
}
.btn-success {
    color: #fff;
    background-color: #43ac6a;
    border-color: #3c9a5f;
}
.btn-success:hover, .btn-success:focus, .btn-success:active, .btn-success.active, .open .dropdown-toggle.btn-success {
    color: #fff;
    background-color: #388f58;
    border-color: #2b6e44;
}
.btn-success:active, .btn-success.active, .open .dropdown-toggle.btn-success {
    background-image: none;
}
.btn-success.disabled, .btn-success[disabled], fieldset[disabled] .btn-success, .btn-success.disabled:hover, .btn-success[disabled]:hover, fieldset[disabled] .btn-success:hover, .btn-success.disabled:focus, .btn-success[disabled]:focus, fieldset[disabled] .btn-success:focus, .btn-success.disabled:active, .btn-success[disabled]:active, fieldset[disabled] .btn-success:active, .btn-success.disabled.active, .btn-success[disabled].active, fieldset[disabled] .btn-success.active {
    background-color: #43ac6a;
    border-color: #3c9a5f;
}
.btn-success .badge {
    color: #43ac6a;
    background-color: #fff;
}
.btn-info {
    color: #fff;
    background-color: #5bc0de;
    border-color: #46b8da;
}
.btn-info:hover, .btn-info:focus, .btn-info:active, .btn-info.active, .open .dropdown-toggle.btn-info {
    color: #fff;
    background-color: #39b3d7;
    border-color: #269abc;
}
.btn-info:active, .btn-info.active, .open .dropdown-toggle.btn-info {
    background-image: none;
}
.btn-info.disabled, .btn-info[disabled], fieldset[disabled] .btn-info, .btn-info.disabled:hover, .btn-info[disabled]:hover, fieldset[disabled] .btn-info:hover, .btn-info.disabled:focus, .btn-info[disabled]:focus, fieldset[disabled] .btn-info:focus, .btn-info.disabled:active, .btn-info[disabled]:active, fieldset[disabled] .btn-info:active, .btn-info.disabled.active, .btn-info[disabled].active, fieldset[disabled] .btn-info.active {
    background-color: #5bc0de;
    border-color: #46b8da;
}
.btn-info .badge {
    color: #5bc0de;
    background-color: #fff;
}
.btn-link {
    font-weight: normal;
    color: #008cba;
    cursor: pointer;
    border-radius: 0;
}
.btn-link, .btn-link:active, .btn-link[disabled], fieldset[disabled] .btn-link {
    background-color: transparent;
    -webkit-box-shadow: none;
    box-shadow: none;
}
.btn-link, .btn-link:hover, .btn-link:focus, .btn-link:active {
    border-color: transparent;
}
.btn-link:hover, .btn-link:focus {
    color: #00526e;
    text-decoration: underline;
    background-color: transparent;
}
.btn-link[disabled]:hover, fieldset[disabled] .btn-link:hover, .btn-link[disabled]:focus, fieldset[disabled] .btn-link:focus {
    color: #999;
    text-decoration: none;
}
.btn-lg {
    padding: 10px 16px;
    font-size: 19px;
    line-height: 1.33;
    border-radius: 0;
}
.btn-sm {
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 0;
}
.btn-xs {
    padding: 1px 5px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 0;
}
.btn-block {
    display: block;
    width: 100%;
    padding-right: 0;
    padding-left: 0;
}
.btn-block+.btn-block {
    margin-top: 5px;
}
input[type="submit"].btn-block, input[type="reset"].btn-block, input[type="button"].btn-block {
    width: 100%}
.fade {
    opacity: 0;
    -webkit-transition: opacity .15s linear;
    transition: opacity .15s linear;
}
.fade.in {
    opacity: 1;
}
.collapse {
    display: none;
}
.collapse.in {
    display: block;
}
.collapsing {
    position: relative;
    height: 0;
    overflow: hidden;
    -webkit-transition: height .35s ease;
    transition: height .35s ease;
}
@font-face {
    font-family: 'Glyphicons Halflings';
    src: url('../fonts/glyphicons-halflings-regular.eot');
    src: url('../fonts/glyphicons-halflings-regular.eot?#iefix') format('embedded-opentype'), url('../fonts/glyphicons-halflings-regular.woff') format('woff'), url('../fonts/glyphicons-halflings-regular.ttf') format('truetype'), url('../fonts/glyphicons-halflings-regular.svg#glyphicons-halflingsregular') format('svg');
}
.glyphicon {
    position: relative;
    top: 1px;
    display: inline-block;
    font-family: 'Glyphicons Halflings';
    -webkit-font-smoothing: antialiased;
    font-style: normal;
    font-weight: normal;
    line-height: 1;
    -moz-osx-font-smoothing: grayscale;
}
.glyphicon:empty {
    width: 1em;
}
.glyphicon-asterisk:before {
    content: "\2a"}
.glyphicon-plus:before {
    content: "\2b"}
.glyphicon-euro:before {
    content: "\20ac"}
.glyphicon-minus:before {
    content: "\2212"}
.glyphicon-cloud:before {
    content: "\2601"}
.glyphicon-envelope:before {
    content: "\2709"}
.glyphicon-pencil:before {
    content: "\270f"}
.glyphicon-glass:before {
    content: "\e001"}
.glyphicon-music:before {
    content: "\e002"}
.glyphicon-search:before {
    content: "\e003"}
.glyphicon-heart:before {
    content: "\e005"}
.glyphicon-star:before {
    content: "\e006"}
.glyphicon-star-empty:before {
    content: "\e007"}
.glyphicon-user:before {
    content: "\e008"}
.glyphicon-film:before {
    content: "\e009"}
.glyphicon-th-large:before {
    content: "\e010"}
.glyphicon-th:before {
    content: "\e011"}
.glyphicon-th-list:before {
    content: "\e012"}
.glyphicon-ok:before {
    content: "\e013"}
.glyphicon-remove:before {
    content: "\e014"}
.glyphicon-zoom-in:before {
    content: "\e015"}
.glyphicon-zoom-out:before {
    content: "\e016"}
.glyphicon-off:before {
    content: "\e017"}
.glyphicon-signal:before {
    content: "\e018"}
.glyphicon-cog:before {
    content: "\e019"}
.glyphicon-trash:before {
    content: "\e020"}
.glyphicon-home:before {
    content: "\e021"}
.glyphicon-file:before {
    content: "\e022"}
.glyphicon-time:before {
    content: "\e023"}
.glyphicon-road:before {
    content: "\e024"}
.glyphicon-download-alt:before {
    content: "\e025"}
.glyphicon-download:before {
    content: "\e026"}
.glyphicon-upload:before {
    content: "\e027"}
.glyphicon-inbox:before {
    content: "\e028"}
.glyphicon-play-circle:before {
    content: "\e029"}
.glyphicon-repeat:before {
    content: "\e030"}
.glyphicon-refresh:before {
    content: "\e031"}
.glyphicon-list-alt:before {
    content: "\e032"}
.glyphicon-lock:before {
    content: "\e033"}
.glyphicon-flag:before {
    content: "\e034"}
.glyphicon-headphones:before {
    content: "\e035"}
.glyphicon-volume-off:before {
    content: "\e036"}
.glyphicon-volume-down:before {
    content: "\e037"}
.glyphicon-volume-up:before {
    content: "\e038"}
.glyphicon-qrcode:before {
    content: "\e039"}
.glyphicon-barcode:before {
    content: "\e040"}
.glyphicon-tag:before {
    content: "\e041"}
.glyphicon-tags:before {
    content: "\e042"}
.glyphicon-book:before {
    content: "\e043"}
.glyphicon-bookmark:before {
    content: "\e044"}
.glyphicon-print:before {
    content: "\e045"}
.glyphicon-camera:before {
    content: "\e046"}
.glyphicon-font:before {
    content: "\e047"}
.glyphicon-bold:before {
    content: "\e048"}
.glyphicon-italic:before {
    content: "\e049"}
.glyphicon-text-height:before {
    content: "\e050"}
.glyphicon-text-width:before {
    content: "\e051"}
.glyphicon-align-left:before {
    content: "\e052"}
.glyphicon-align-center:before {
    content: "\e053"}
.glyphicon-align-right:before {
    content: "\e054"}
.glyphicon-align-justify:before {
    content: "\e055"}
.glyphicon-list:before {
    content: "\e056"}
.glyphicon-indent-left:before {
    content: "\e057"}
.glyphicon-indent-right:before {
    content: "\e058"}
.glyphicon-facetime-video:before {
    content: "\e059"}
.glyphicon-picture:before {
    content: "\e060"}
.glyphicon-map-marker:before {
    content: "\e062"}
.glyphicon-adjust:before {
    content: "\e063"}
.glyphicon-tint:before {
    content: "\e064"}
.glyphicon-edit:before {
    content: "\e065"}
.glyphicon-share:before {
    content: "\e066"}
.glyphicon-check:before {
    content: "\e067"}
.glyphicon-move:before {
    content: "\e068"}
.glyphicon-step-backward:before {
    content: "\e069"}
.glyphicon-fast-backward:before {
    content: "\e070"}
.glyphicon-backward:before {
    content: "\e071"}
.glyphicon-play:before {
    content: "\e072"}
.glyphicon-pause:before {
    content: "\e073"}
.glyphicon-stop:before {
    content: "\e074"}
.glyphicon-forward:before {
    content: "\e075"}
.glyphicon-fast-forward:before {
    content: "\e076"}
.glyphicon-step-forward:before {
    content: "\e077"}
.glyphicon-eject:before {
    content: "\e078"}
.glyphicon-chevron-left:before {
    content: "\e079"}
.glyphicon-chevron-right:before {
    content: "\e080"}
.glyphicon-plus-sign:before {
    content: "\e081"}
.glyphicon-minus-sign:before {
    content: "\e082"}
.glyphicon-remove-sign:before {
    content: "\e083"}
.glyphicon-ok-sign:before {
    content: "\e084"}
.glyphicon-question-sign:before {
    content: "\e085"}
.glyphicon-info-sign:before {
    content: "\e086"}
.glyphicon-screenshot:before {
    content: "\e087"}
.glyphicon-remove-circle:before {
    content: "\e088"}
.glyphicon-ok-circle:before {
    content: "\e089"}
.glyphicon-ban-circle:before {
    content: "\e090"}
.glyphicon-arrow-left:before {
    content: "\e091"}
.glyphicon-arrow-right:before {
    content: "\e092"}
.glyphicon-arrow-up:before {
    content: "\e093"}
.glyphicon-arrow-down:before {
    content: "\e094"}
.glyphicon-share-alt:before {
    content: "\e095"}
.glyphicon-resize-full:before {
    content: "\e096"}
.glyphicon-resize-small:before {
    content: "\e097"}
.glyphicon-exclamation-sign:before {
    content: "\e101"}
.glyphicon-gift:before {
    content: "\e102"}
.glyphicon-leaf:before {
    content: "\e103"}
.glyphicon-fire:before {
    content: "\e104"}
.glyphicon-eye-open:before {
    content: "\e105"}
.glyphicon-eye-close:before {
    content: "\e106"}
.glyphicon-warning-sign:before {
    content: "\e107"}
.glyphicon-plane:before {
    content: "\e108"}
.glyphicon-calendar:before {
    content: "\e109"}
.glyphicon-random:before {
    content: "\e110"}
.glyphicon-comment:before {
    content: "\e111"}
.glyphicon-magnet:before {
    content: "\e112"}
.glyphicon-chevron-up:before {
    content: "\e113"}
.glyphicon-chevron-down:before {
    content: "\e114"}
.glyphicon-retweet:before {
    content: "\e115"}
.glyphicon-shopping-cart:before {
    content: "\e116"}
.glyphicon-folder-close:before {
    content: "\e117"}
.glyphicon-folder-open:before {
    content: "\e118"}
.glyphicon-resize-vertical:before {
    content: "\e119"}
.glyphicon-resize-horizontal:before {
    content: "\e120"}
.glyphicon-hdd:before {
    content: "\e121"}
.glyphicon-bullhorn:before {
    content: "\e122"}
.glyphicon-bell:before {
    content: "\e123"}
.glyphicon-certificate:before {
    content: "\e124"}
.glyphicon-thumbs-up:before {
    content: "\e125"}
.glyphicon-thumbs-down:before {
    content: "\e126"}
.glyphicon-hand-right:before {
    content: "\e127"}
.glyphicon-hand-left:before {
    content: "\e128"}
.glyphicon-hand-up:before {
    content: "\e129"}
.glyphicon-hand-down:before {
    content: "\e130"}
.glyphicon-circle-arrow-right:before {
    content: "\e131"}
.glyphicon-circle-arrow-left:before {
    content: "\e132"}
.glyphicon-circle-arrow-up:before {
    content: "\e133"}
.glyphicon-circle-arrow-down:before {
    content: "\e134"}
.glyphicon-globe:before {
    content: "\e135"}
.glyphicon-wrench:before {
    content: "\e136"}
.glyphicon-tasks:before {
    content: "\e137"}
.glyphicon-filter:before {
    content: "\e138"}
.glyphicon-briefcase:before {
    content: "\e139"}
.glyphicon-fullscreen:before {
    content: "\e140"}
.glyphicon-dashboard:before {
    content: "\e141"}
.glyphicon-paperclip:before {
    content: "\e142"}
.glyphicon-heart-empty:before {
    content: "\e143"}
.glyphicon-link:before {
    content: "\e144"}
.glyphicon-phone:before {
    content: "\e145"}
.glyphicon-pushpin:before {
    content: "\e146"}
.glyphicon-usd:before {
    content: "\e148"}
.glyphicon-gbp:before {
    content: "\e149"}
.glyphicon-sort:before {
    content: "\e150"}
.glyphicon-sort-by-alphabet:before {
    content: "\e151"}
.glyphicon-sort-by-alphabet-alt:before {
    content: "\e152"}
.glyphicon-sort-by-order:before {
    content: "\e153"}
.glyphicon-sort-by-order-alt:before {
    content: "\e154"}
.glyphicon-sort-by-attributes:before {
    content: "\e155"}
.glyphicon-sort-by-attributes-alt:before {
    content: "\e156"}
.glyphicon-unchecked:before {
    content: "\e157"}
.glyphicon-expand:before {
    content: "\e158"}
.glyphicon-collapse-down:before {
    content: "\e159"}
.glyphicon-collapse-up:before {
    content: "\e160"}
.glyphicon-log-in:before {
    content: "\e161"}
.glyphicon-flash:before {
    content: "\e162"}
.glyphicon-log-out:before {
    content: "\e163"}
.glyphicon-new-window:before {
    content: "\e164"}
.glyphicon-record:before {
    content: "\e165"}
.glyphicon-save:before {
    content: "\e166"}
.glyphicon-open:before {
    content: "\e167"}
.glyphicon-saved:before {
    content: "\e168"}
.glyphicon-import:before {
    content: "\e169"}
.glyphicon-export:before {
    content: "\e170"}
.glyphicon-send:before {
    content: "\e171"}
.glyphicon-floppy-disk:before {
    content: "\e172"}
.glyphicon-floppy-saved:before {
    content: "\e173"}
.glyphicon-floppy-remove:before {
    content: "\e174"}
.glyphicon-floppy-save:before {
    content: "\e175"}
.glyphicon-floppy-open:before {
    content: "\e176"}
.glyphicon-credit-card:before {
    content: "\e177"}
.glyphicon-transfer:before {
    content: "\e178"}
.glyphicon-cutlery:before {
    content: "\e179"}
.glyphicon-header:before {
    content: "\e180"}
.glyphicon-compressed:before {
    content: "\e181"}
.glyphicon-earphone:before {
    content: "\e182"}
.glyphicon-phone-alt:before {
    content: "\e183"}
.glyphicon-tower:before {
    content: "\e184"}
.glyphicon-stats:before {
    content: "\e185"}
.glyphicon-sd-video:before {
    content: "\e186"}
.glyphicon-hd-video:before {
    content: "\e187"}
.glyphicon-subtitles:before {
    content: "\e188"}
.glyphicon-sound-stereo:before {
    content: "\e189"}
.glyphicon-sound-dolby:before {
    content: "\e190"}
.glyphicon-sound-5-1:before {
    content: "\e191"}
.glyphicon-sound-6-1:before {
    content: "\e192"}
.glyphicon-sound-7-1:before {
    content: "\e193"}
.glyphicon-copyright-mark:before {
    content: "\e194"}
.glyphicon-registration-mark:before {
    content: "\e195"}
.glyphicon-cloud-download:before {
    content: "\e197"}
.glyphicon-cloud-upload:before {
    content: "\e198"}
.glyphicon-tree-conifer:before {
    content: "\e199"}
.glyphicon-tree-deciduous:before {
    content: "\e200"}
.caret {
    display: inline-block;
    width: 0;
    height: 0;
    margin-left: 2px;
    vertical-align: middle;
    border-top: 4px solid;
    border-right: 4px solid transparent;
    border-left: 4px solid transparent;
}
.dropdown {
    position: relative;
}
.dropdown-toggle:focus {
    outline: 0;
}
.dropdown-menu {
    position: absolute;
    top: 100%;
    left: 0;
    z-index: 1000;
    display: none;
    float: left;
    min-width: 160px;
    padding: 5px 0;
    margin: 2px 0 0;
    font-size: 15px;
    list-style: none;
    background-color: #fff;
    border: 1px solid #ccc;
    border: 1px solid rgba(0, 0, 0, 0.15);
    border-radius: 0;
    -webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
    box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
    background-clip: padding-box;
}
.dropdown-menu.pull-right {
    right: 0;
    left: auto;
}
.dropdown-menu .divider {
    height: 1px;
    margin: 9.5px 0;
    overflow: hidden;
    background-color: rgba(0, 0, 0, 0.2);
}
.dropdown-menu>li>a {
    display: block;
    padding: 3px 20px;
    clear: both;
    font-weight: normal;
    line-height: 1.428571429;
    color: #555;
    white-space: nowrap;
}
.dropdown-menu>li>a:hover, .dropdown-menu>li>a:focus {
    color: #262626;
    text-decoration: none;
    background-color: #eee;
}
.dropdown-menu>.active>a, .dropdown-menu>.active>a:hover, .dropdown-menu>.active>a:focus {
    color: #fff;
    text-decoration: none;
    background-color: #008cba;
    outline: 0;
}
.dropdown-menu>.disabled>a, .dropdown-menu>.disabled>a:hover, .dropdown-menu>.disabled>a:focus {
    color: #999;
}
.dropdown-menu>.disabled>a:hover, .dropdown-menu>.disabled>a:focus {
    text-decoration: none;
    cursor: not-allowed;
    background-color: transparent;
    background-image: none;
    filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
}
.open>.dropdown-menu {
    display: block;
}
.open>a {
    outline: 0;
}
.dropdown-header {
    display: block;
    padding: 3px 20px;
    font-size: 12px;
    line-height: 1.428571429;
    color: #999;
}
.dropdown-backdrop {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 990;
}
.pull-right>.dropdown-menu {
    right: 0;
    left: auto;
}
.dropup .caret, .navbar-fixed-bottom .dropdown .caret {
    border-top: 0;
    border-bottom: 4px solid;
    content: ""}
.dropup .dropdown-menu, .navbar-fixed-bottom .dropdown .dropdown-menu {
    top: auto;
    bottom: 100%;
    margin-bottom: 1px;
}
@media(min-width:768px) {
    .navbar-right .dropdown-menu {
    right: 0;
    left: auto;
}
}.btn-group, .btn-group-vertical {
    position: relative;
    display: inline-block;
    vertical-align: middle;
}
.btn-group>.btn, .btn-group-vertical>.btn {
    position: relative;
    float: left;
}
.btn-group>.btn:hover, .btn-group-vertical>.btn:hover, .btn-group>.btn:focus, .btn-group-vertical>.btn:focus, .btn-group>.btn:active, .btn-group-vertical>.btn:active, .btn-group>.btn.active, .btn-group-vertical>.btn.active {
    z-index: 2;
}
.btn-group>.btn:focus, .btn-group-vertical>.btn:focus {
    outline: 0;
}
.btn-group .btn+.btn, .btn-group .btn+.btn-group, .btn-group .btn-group+.btn, .btn-group .btn-group+.btn-group {
    margin-left: -1px;
}
.btn-toolbar:before, .btn-toolbar:after {
    display: table;
    content: " "}
.btn-toolbar:after {
    clear: both;
}
.btn-toolbar:before, .btn-toolbar:after {
    display: table;
    content: " "}
.btn-toolbar:after {
    clear: both;
}
.btn-toolbar:before, .btn-toolbar:after {
    display: table;
    content: " "}
.btn-toolbar:after {
    clear: both;
}
.btn-toolbar:before, .btn-toolbar:after {
    display: table;
    content: " "}
.btn-toolbar:after {
    clear: both;
}
.btn-toolbar:before, .btn-toolbar:after {
    display: table;
    content: " "}
.btn-toolbar:after {
    clear: both;
}
.btn-toolbar .btn-group {
    float: left;
}
.btn-toolbar>.btn+.btn, .btn-toolbar>.btn-group+.btn, .btn-toolbar>.btn+.btn-group, .btn-toolbar>.btn-group+.btn-group {
    margin-left: 5px;
}
.btn-group>.btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
    border-radius: 0;
}
.btn-group>.btn:first-child {
    margin-left: 0;
}
.btn-group>.btn:first-child:not(:last-child):not(.dropdown-toggle) {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}
.btn-group>.btn:last-child:not(:first-child), .btn-group>.dropdown-toggle:not(:first-child) {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}
.btn-group>.btn-group {
    float: left;
}
.btn-group>.btn-group:not(:first-child):not(:last-child)>.btn {
    border-radius: 0;
}
.btn-group>.btn-group:first-child>.btn:last-child, .btn-group>.btn-group:first-child>.dropdown-toggle {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}
.btn-group>.btn-group:last-child>.btn:first-child {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}
.btn-group .dropdown-toggle:active, .btn-group.open .dropdown-toggle {
    outline: 0;
}
.btn-group-xs>.btn {
    padding: 1px 5px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 0;
}
.btn-group-sm>.btn {
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 0;
}
.btn-group-lg>.btn {
    padding: 10px 16px;
    font-size: 19px;
    line-height: 1.33;
    border-radius: 0;
}
.btn-group>.btn+.dropdown-toggle {
    padding-right: 8px;
    padding-left: 8px;
}
.btn-group>.btn-lg+.dropdown-toggle {
    padding-right: 12px;
    padding-left: 12px;
}
.btn-group.open .dropdown-toggle {
    -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
    box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
.btn-group.open .dropdown-toggle.btn-link {
    -webkit-box-shadow: none;
    box-shadow: none;
}
.btn .caret {
    margin-left: 0;
}
.btn-lg .caret {
    border-width: 5px 5px 0;
    border-bottom-width: 0;
}
.dropup .btn-lg .caret {
    border-width: 0 5px 5px;
}
.btn-group-vertical>.btn, .btn-group-vertical>.btn-group, .btn-group-vertical>.btn-group>.btn {
    display: block;
    float: none;
    width: 100%;
    max-width: 100%}
.btn-group-vertical>.btn-group:before, .btn-group-vertical>.btn-group:after {
    display: table;
    content: " "}
.btn-group-vertical>.btn-group:after {
    clear: both;
}
.btn-group-vertical>.btn-group:before, .btn-group-vertical>.btn-group:after {
    display: table;
    content: " "}
.btn-group-vertical>.btn-group:after {
    clear: both;
}
.btn-group-vertical>.btn-group:before, .btn-group-vertical>.btn-group:after {
    display: table;
    content: " "}
.btn-group-vertical>.btn-group:after {
    clear: both;
}
.btn-group-vertical>.btn-group:before, .btn-group-vertical>.btn-group:after {
    display: table;
    content: " "}
.btn-group-vertical>.btn-group:after {
    clear: both;
}
.btn-group-vertical>.btn-group:before, .btn-group-vertical>.btn-group:after {
    display: table;
    content: " "}
.btn-group-vertical>.btn-group:after {
    clear: both;
}
.btn-group-vertical>.btn-group>.btn {
    float: none;
}
.btn-group-vertical>.btn+.btn, .btn-group-vertical>.btn+.btn-group, .btn-group-vertical>.btn-group+.btn, .btn-group-vertical>.btn-group+.btn-group {
    margin-top: -1px;
    margin-left: 0;
}
.btn-group-vertical>.btn:not(:first-child):not(:last-child) {
    border-radius: 0;
}
.btn-group-vertical>.btn:first-child:not(:last-child) {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}
.btn-group-vertical>.btn:last-child:not(:first-child) {
    border-top-right-radius: 0;
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}
.btn-group-vertical>.btn-group:not(:first-child):not(:last-child)>.btn {
    border-radius: 0;
}
.btn-group-vertical>.btn-group:first-child>.btn:last-child, .btn-group-vertical>.btn-group:first-child>.dropdown-toggle {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}
.btn-group-vertical>.btn-group:last-child>.btn:first-child {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}
.btn-group-justified {
    display: table;
    width: 100%;
    border-collapse: separate;
    table-layout: fixed;
}
.btn-group-justified>.btn, .btn-group-justified>.btn-group {
    display: table-cell;
    float: none;
    width: 1%}
.btn-group-justified>.btn-group .btn {
    width: 100%}
[data-toggle="buttons"]>.btn>input[type="radio"], [data-toggle="buttons"]>.btn>input[type="checkbox"] {
    display: none;
}
.input-group {
    position: relative;
    display: table;
    border-collapse: separate;
}
.input-group[class*="col-"] {
    float: none;
    padding-right: 0;
    padding-left: 0;
}
.input-group .form-control {
    width: 100%;
    margin-bottom: 0;
}
.input-group-lg>.form-control, .input-group-lg>.input-group-addon, .input-group-lg>.input-group-btn>.btn {
    height: 48px;
    padding: 10px 16px;
    font-size: 19px;
    line-height: 1.33;
    border-radius: 0;
}
select.input-group-lg>.form-control, select.input-group-lg>.input-group-addon, select.input-group-lg>.input-group-btn>.btn {
    height: 48px;
    line-height: 48px;
}
textarea.input-group-lg>.form-control, textarea.input-group-lg>.input-group-addon, textarea.input-group-lg>.input-group-btn>.btn {
    height: auto;
}
.input-group-sm>.form-control, .input-group-sm>.input-group-addon, .input-group-sm>.input-group-btn>.btn {
    height: 30px;
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 0;
}
select.input-group-sm>.form-control, select.input-group-sm>.input-group-addon, select.input-group-sm>.input-group-btn>.btn {
    height: 30px;
    line-height: 30px;
}
textarea.input-group-sm>.form-control, textarea.input-group-sm>.input-group-addon, textarea.input-group-sm>.input-group-btn>.btn {
    height: auto;
}
.input-group-addon, .input-group-btn, .input-group .form-control {
    display: table-cell;
}
.input-group-addon:not(:first-child):not(:last-child), .input-group-btn:not(:first-child):not(:last-child), .input-group .form-control:not(:first-child):not(:last-child) {
    border-radius: 0;
}
.input-group-addon, .input-group-btn {
    width: 1%;
    white-space: nowrap;
    vertical-align: middle;
}
.input-group-addon {
    padding: 6px 12px;
    font-size: 15px;
    font-weight: normal;
    line-height: 1;
    color: #6f6f6f;
    text-align: center;
    background-color: #eee;
    border: 1px solid #ccc;
    border-radius: 0;
}
.input-group-addon.input-sm {
    padding: 5px 10px;
    font-size: 12px;
    border-radius: 0;
}
.input-group-addon.input-lg {
    padding: 10px 16px;
    font-size: 19px;
    border-radius: 0;
}
.input-group-addon input[type="radio"], .input-group-addon input[type="checkbox"] {
    margin-top: 0;
}
.input-group .form-control:first-child, .input-group-addon:first-child, .input-group-btn:first-child>.btn, .input-group-btn:first-child>.dropdown-toggle, .input-group-btn:last-child>.btn:not(:last-child):not(.dropdown-toggle) {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}
.input-group-addon:first-child {
    border-right: 0;
}
.input-group .form-control:last-child, .input-group-addon:last-child, .input-group-btn:last-child>.btn, .input-group-btn:last-child>.dropdown-toggle, .input-group-btn:first-child>.btn:not(:first-child) {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}
.input-group-addon:last-child {
    border-left: 0;
}
.input-group-btn {
    position: relative;
    white-space: nowrap;
}
.input-group-btn:first-child>.btn {
    margin-right: -1px;
}
.input-group-btn:last-child>.btn {
    margin-left: -1px;
}
.input-group-btn>.btn {
    position: relative;
}
.input-group-btn>.btn+.btn {
    margin-left: -4px;
}
.input-group-btn>.btn:hover, .input-group-btn>.btn:active {
    z-index: 2;
}
.nav {
    font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
    padding-left: 0;
    margin-bottom: 0;
    list-style: none;
}
.nav:before, .nav:after {
    display: table;
    content: " "}
.nav:after {
    clear: both;
}
.nav:before, .nav:after {
    display: table;
    content: " "}
.nav:after {
    clear: both;
}
.nav:before, .nav:after {
    display: table;
    content: " "}
.nav:after {
    clear: both;
}
.nav:before, .nav:after {
    display: table;
    content: " "}
.nav:after {
    clear: both;
}
.nav:before, .nav:after {
    display: table;
    content: " "}
.nav:after {
    clear: both;
}
.nav>li {
    position: relative;
    display: block;
}
.nav>li>a {
    position: relative;
    display: block;
    padding: 10px 15px;
}
.nav>li>a:hover, .nav>li>a:focus {
    text-decoration: none;
    background-color: #eee;
}
.nav>li.disabled>a {
    color: #999;
}
.nav>li.disabled>a:hover, .nav>li.disabled>a:focus {
    color: #999;
    text-decoration: none;
    cursor: not-allowed;
    background-color: transparent;
}
.nav .open>a, .nav .open>a:hover, .nav .open>a:focus {
    background-color: #eee;
    border-color: #008cba;
}
.nav .nav-divider {
    height: 1px;
    margin: 9.5px 0;
    overflow: hidden;
    background-color: #e5e5e5;
}
.nav>li>a>img {
    max-width: none;
}
.nav-tabs {
    border-bottom: 1px solid #ddd;
}
.nav-tabs>li {
    float: left;
    margin-bottom: -1px;
}
.nav-tabs>li>a {
    margin-right: 2px;
    line-height: 1.428571429;
    border: 1px solid transparent;
    border-radius: 0;
}
.nav-tabs>li>a:hover {
    border-color: #eee #eee #ddd;
}
.nav-tabs>li.active>a, .nav-tabs>li.active>a:hover, .nav-tabs>li.active>a:focus {
    color: #6f6f6f;
    cursor: default;
    background-color: #fff;
    border: 1px solid #ddd;
    border-bottom-color: transparent;
}
.nav-tabs.nav-justified {
    width: 100%;
    border-bottom: 0;
}
.nav-tabs.nav-justified>li {
    float: none;
}
.nav-tabs.nav-justified>li>a {
    margin-bottom: 5px;
    text-align: center;
}
.nav-tabs.nav-justified>.dropdown .dropdown-menu {
    top: auto;
    left: auto;
}
@media(min-width:768px) {
    .nav-tabs.nav-justified>li {
    display: table-cell;
    width: 1%}
.nav-tabs.nav-justified>li>a {
    margin-bottom: 0;
}
}.nav-tabs.nav-justified>li>a {
    margin-right: 0;
    border-radius: 0;
}
.nav-tabs.nav-justified>.active>a, .nav-tabs.nav-justified>.active>a:hover, .nav-tabs.nav-justified>.active>a:focus {
    border: 1px solid #ddd;
}
@media(min-width:768px) {
    .nav-tabs.nav-justified>li>a {
    border-bottom: 1px solid #ddd;
    border-radius: 0;
}
.nav-tabs.nav-justified>.active>a, .nav-tabs.nav-justified>.active>a:hover, .nav-tabs.nav-justified>.active>a:focus {
    border-bottom-color: #fff;
}
}.nav-pills>li {
    float: left;
}
.nav-pills>li>a {
    border-radius: 0;
}
.nav-pills>li+li {
    margin-left: 2px;
}
.nav-pills>li.active>a, .nav-pills>li.active>a:hover, .nav-pills>li.active>a:focus {
    color: #fff;
    background-color: #008cba;
}
.nav-stacked>li {
    float: none;
}
.nav-stacked>li+li {
    margin-top: 2px;
    margin-left: 0;
}
.nav-justified {
    width: 100%}
.nav-justified>li {
    float: none;
}
.nav-justified>li>a {
    margin-bottom: 5px;
    text-align: center;
}
.nav-justified>.dropdown .dropdown-menu {
    top: auto;
    left: auto;
}
@media(min-width:768px) {
    .nav-justified>li {
    display: table-cell;
    width: 1%}
.nav-justified>li>a {
    margin-bottom: 0;
}
}.nav-tabs-justified {
    border-bottom: 0;
}
.nav-tabs-justified>li>a {
    margin-right: 0;
    border-radius: 0;
}
.nav-tabs-justified>.active>a, .nav-tabs-justified>.active>a:hover, .nav-tabs-justified>.active>a:focus {
    border: 1px solid #ddd;
}
@media(min-width:768px) {
    .nav-tabs-justified>li>a {
    border-bottom: 1px solid #ddd;
    border-radius: 0;
}
.nav-tabs-justified>.active>a, .nav-tabs-justified>.active>a:hover, .nav-tabs-justified>.active>a:focus {
    border-bottom-color: #fff;
}
}.tab-content>.tab-pane {
    display: none;
}
.tab-content>.active {
    display: block;
}
.nav-tabs .dropdown-menu {
    margin-top: -1px;
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}
.navbar {
    position: relative;
    min-height: 45px;
    margin-bottom: 21px;
    border: 1px solid transparent;
}
.navbar:before, .navbar:after {
    display: table;
    content: " "}
.navbar:after {
    clear: both;
}
.navbar:before, .navbar:after {
    display: table;
    content: " "}
.navbar:after {
    clear: both;
}
.navbar:before, .navbar:after {
    display: table;
    content: " "}
.navbar:after {
    clear: both;
}
.navbar:before, .navbar:after {
    display: table;
    content: " "}
.navbar:after {
    clear: both;
}
.navbar:before, .navbar:after {
    display: table;
    content: " "}
.navbar:after {
    clear: both;
}
@media(min-width:768px) {
    .navbar {
    border-radius: 0;
}
}.navbar-header:before, .navbar-header:after {
    display: table;
    content: " "}
.navbar-header:after {
    clear: both;
}
.navbar-header:before, .navbar-header:after {
    display: table;
    content: " "}
.navbar-header:after {
    clear: both;
}
.navbar-header:before, .navbar-header:after {
    display: table;
    content: " "}
.navbar-header:after {
    clear: both;
}
.navbar-header:before, .navbar-header:after {
    display: table;
    content: " "}
.navbar-header:after {
    clear: both;
}
.navbar-header:before, .navbar-header:after {
    display: table;
    content: " "}
.navbar-header:after {
    clear: both;
}
@media(min-width:768px) {
    .navbar-header {
    float: left;
}
}.navbar-collapse {
    max-height: 340px;
    padding-right: 15px;
    padding-left: 15px;
    overflow-x: visible;
    border-top: 1px solid transparent;
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1);
    -webkit-overflow-scrolling: touch;
}
.navbar-collapse:before, .navbar-collapse:after {
    display: table;
    content: " "}
.navbar-collapse:after {
    clear: both;
}
.navbar-collapse:before, .navbar-collapse:after {
    display: table;
    content: " "}
.navbar-collapse:after {
    clear: both;
}
.navbar-collapse:before, .navbar-collapse:after {
    display: table;
    content: " "}
.navbar-collapse:after {
    clear: both;
}
.navbar-collapse:before, .navbar-collapse:after {
    display: table;
    content: " "}
.navbar-collapse:after {
    clear: both;
}
.navbar-collapse:before, .navbar-collapse:after {
    display: table;
    content: " "}
.navbar-collapse:after {
    clear: both;
}
.navbar-collapse.in {
    overflow-y: auto;
}
@media(min-width:768px) {
    .navbar-collapse {
    width: auto;
    border-top: 0;
    box-shadow: none;
}
.navbar-collapse.collapse {
    display: block!important;
    height: auto!important;
    padding-bottom: 0;
    overflow: visible!important;
}
.navbar-collapse.in {
    overflow-y: visible;
}
.navbar-fixed-top .navbar-collapse, .navbar-static-top .navbar-collapse, .navbar-fixed-bottom .navbar-collapse {
    padding-right: 0;
    padding-left: 0;
}
}.container>.navbar-header, .container>.navbar-collapse {
    margin-right: -15px;
    margin-left: -15px;
}
@media(min-width:768px) {
    .container>.navbar-header, .container>.navbar-collapse {
    margin-right: 0;
    margin-left: 0;
}
}.navbar-static-top {
    z-index: 1000;
    border-width: 0 0 1px;
}
@media(min-width:768px) {
    .navbar-static-top {
    border-radius: 0;
}
}.navbar-fixed-top, .navbar-fixed-bottom {
    position: fixed;
    right: 0;
    left: 0;
    z-index: 1030;
}
@media(min-width:768px) {
    .navbar-fixed-top, .navbar-fixed-bottom {
    border-radius: 0;
}
}.navbar-fixed-top {
    top: 0;
    border-width: 0 0 1px;
}
.navbar-fixed-bottom {
    bottom: 0;
    margin-bottom: 0;
    border-width: 1px 0 0;
}
.navbar-brand {
    font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
    float: left;
    padding: 12px 15px;
    font-size: 19px;
    line-height: 21px;
}
.navbar-brand:hover, .navbar-brand:focus {
    text-decoration: none;
}
@media(min-width:768px) {
    .navbar>.container .navbar-brand {
    margin-left: -15px;
}
}.navbar-toggle {
    position: relative;
    float: right;
    padding: 9px 10px;
    margin-top: 5.5px;
    margin-right: 15px;
    margin-bottom: 5.5px;
    background-color: transparent;
    background-image: none;
    border: 1px solid transparent;
    border-radius: 0;
}
.navbar-toggle .icon-bar {
    display: block;
    width: 22px;
    height: 2px;
    border-radius: 1px;
}
.navbar-toggle .icon-bar+.icon-bar {
    margin-top: 4px;
}
@media(min-width:768px) {
    .navbar-toggle {
    display: none;
}
}.navbar-nav {
    margin: 6px -15px;
}
.navbar-nav>li>a {
    padding-top: 10px;
    padding-bottom: 10px;
    line-height: 21px;
}
@media(max-width:767px) {
    .navbar-nav .open .dropdown-menu {
    position: static;
    float: none;
    width: auto;
    margin-top: 0;
    background-color: transparent;
    border: 0;
    box-shadow: none;
}
.navbar-nav .open .dropdown-menu>li>a, .navbar-nav .open .dropdown-menu .dropdown-header {
    padding: 5px 15px 5px 25px;
}
.navbar-nav .open .dropdown-menu>li>a {
    line-height: 21px;
}
.navbar-nav .open .dropdown-menu>li>a:hover, .navbar-nav .open .dropdown-menu>li>a:focus {
    background-image: none;
}
}@media(min-width:768px) {
    .navbar-nav {
    float: left;
    margin: 0;
}
.navbar-nav>li {
    float: left;
}
.navbar-nav>li>a {
    padding-top: 12px;
    padding-bottom: 12px;
}
.navbar-nav.navbar-right:last-child {
    margin-right: -15px;
}
}@media(min-width:768px) {
    .navbar-left {
    float: left!important;
}
.navbar-right {
    float: right!important;
}
}.navbar-form {
    padding: 10px 15px;
    margin-top: 5px;
    margin-right: -15px;
    margin-bottom: 5px;
    margin-left: -15px;
    border-top: 1px solid transparent;
    border-bottom: 1px solid transparent;
    -webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
}
@media(min-width:768px) {
    .navbar-form .form-group {
    display: inline-block;
    margin-bottom: 0;
    vertical-align: middle;
}
.navbar-form .form-control {
    display: inline-block;
}
.navbar-form select.form-control {
    width: auto;
}
.navbar-form .radio, .navbar-form .checkbox {
    display: inline-block;
    padding-left: 0;
    margin-top: 0;
    margin-bottom: 0;
}
.navbar-form .radio input[type="radio"], .navbar-form .checkbox input[type="checkbox"] {
    float: none;
    margin-left: 0;
}
}@media(max-width:767px) {
    .navbar-form .form-group {
    margin-bottom: 5px;
}
}@media(min-width:768px) {
    .navbar-form {
    width: auto;
    padding-top: 0;
    padding-bottom: 0;
    margin-right: 0;
    margin-left: 0;
    border: 0;
    -webkit-box-shadow: none;
    box-shadow: none;
}
.navbar-form.navbar-right:last-child {
    margin-right: -15px;
}
}.navbar-nav>li>.dropdown-menu {
    margin-top: 0;
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}
.navbar-fixed-bottom .navbar-nav>li>.dropdown-menu {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}
.navbar-nav.pull-right>li>.dropdown-menu, .navbar-nav>li>.dropdown-menu.pull-right {
    right: 0;
    left: auto;
}
.navbar-btn {
    margin-top: 5px;
    margin-bottom: 5px;
}
.navbar-btn.btn-sm {
    margin-top: 7.5px;
    margin-bottom: 7.5px;
}
.navbar-btn.btn-xs {
    margin-top: 11.5px;
    margin-bottom: 11.5px;
}
.navbar-text {
    margin-top: 12px;
    margin-bottom: 12px;
}
@media(min-width:768px) {
    .navbar-text {
    float: left;
    margin-right: 15px;
    margin-left: 15px;
}
.navbar-text.navbar-right:last-child {
    margin-right: 0;
}
}.navbar-default {
    background-color: #333;
    border-color: #222;
}
.navbar-default .navbar-brand {
    color: #fff;
}
.navbar-default .navbar-brand:hover, .navbar-default .navbar-brand:focus {
    color: #fff;
    background-color: transparent;
}
.navbar-default .navbar-text {
    color: #fff;
}
.navbar-default .navbar-nav>li>a {
    color: #fff;
}
.navbar-default .navbar-nav>li>a:hover, .navbar-default .navbar-nav>li>a:focus {
    color: #fff;
    background-color: #272727;
}
.navbar-default .navbar-nav>.active>a, .navbar-default .navbar-nav>.active>a:hover, .navbar-default .navbar-nav>.active>a:focus {
    color: #fff;
    background-color: #272727;
}
.navbar-default .navbar-nav>.disabled>a, .navbar-default .navbar-nav>.disabled>a:hover, .navbar-default .navbar-nav>.disabled>a:focus {
    color: #ccc;
    background-color: transparent;
}
.navbar-default .navbar-toggle {
    border-color: transparent;
}
.navbar-default .navbar-toggle:hover, .navbar-default .navbar-toggle:focus {
    background-color: transparent;
}
.navbar-default .navbar-toggle .icon-bar {
    background-color: #fff;
}
.navbar-default .navbar-collapse, .navbar-default .navbar-form {
    border-color: #222;
}
.navbar-default .navbar-nav>.open>a, .navbar-default .navbar-nav>.open>a:hover, .navbar-default .navbar-nav>.open>a:focus {
    color: #fff;
    background-color: #272727;
}
@media(max-width:767px) {
    .navbar-default .navbar-nav .open .dropdown-menu>li>a {
    color: #fff;
}
.navbar-default .navbar-nav .open .dropdown-menu>li>a:hover, .navbar-default .navbar-nav .open .dropdown-menu>li>a:focus {
    color: #fff;
    background-color: #272727;
}
.navbar-default .navbar-nav .open .dropdown-menu>.active>a, .navbar-default .navbar-nav .open .dropdown-menu>.active>a:hover, .navbar-default .navbar-nav .open .dropdown-menu>.active>a:focus {
    color: #fff;
    background-color: #272727;
}
.navbar-default .navbar-nav .open .dropdown-menu>.disabled>a, .navbar-default .navbar-nav .open .dropdown-menu>.disabled>a:hover, .navbar-default .navbar-nav .open .dropdown-menu>.disabled>a:focus {
    color: #ccc;
    background-color: transparent;
}
}.navbar-default .navbar-link {
    color: #fff;
}
.navbar-default .navbar-link:hover {
    color: #fff;
}
.navbar-inverse {
    background-color: #008cba;
    border-color: #006687;
}
.navbar-inverse .navbar-brand {
    color: #fff;
}
.navbar-inverse .navbar-brand:hover, .navbar-inverse .navbar-brand:focus {
    color: #fff;
    background-color: transparent;
}
.navbar-inverse .navbar-text {
    color: #fff;
}
.navbar-inverse .navbar-nav>li>a {
    color: #fff;
}
.navbar-inverse .navbar-nav>li>a:hover, .navbar-inverse .navbar-nav>li>a:focus {
    color: #fff;
    background-color: #006687;
}
.navbar-inverse .navbar-nav>.active>a, .navbar-inverse .navbar-nav>.active>a:hover, .navbar-inverse .navbar-nav>.active>a:focus {
    color: #fff;
    background-color: #006687;
}
.navbar-inverse .navbar-nav>.disabled>a, .navbar-inverse .navbar-nav>.disabled>a:hover, .navbar-inverse .navbar-nav>.disabled>a:focus {
    color: #444;
    background-color: transparent;
}
.navbar-inverse .navbar-toggle {
    border-color: transparent;
}
.navbar-inverse .navbar-toggle:hover, .navbar-inverse .navbar-toggle:focus {
    background-color: transparent;
}
.navbar-inverse .navbar-toggle .icon-bar {
    background-color: #fff;
}
.navbar-inverse .navbar-collapse, .navbar-inverse .navbar-form {
    border-color: #007196;
}
.navbar-inverse .navbar-nav>.open>a, .navbar-inverse .navbar-nav>.open>a:hover, .navbar-inverse .navbar-nav>.open>a:focus {
    color: #fff;
    background-color: #006687;
}
@media(max-width:767px) {
    .navbar-inverse .navbar-nav .open .dropdown-menu>.dropdown-header {
    border-color: #006687;
}
.navbar-inverse .navbar-nav .open .dropdown-menu .divider {
    background-color: #006687;
}
.navbar-inverse .navbar-nav .open .dropdown-menu>li>a {
    color: #fff;
}
.navbar-inverse .navbar-nav .open .dropdown-menu>li>a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu>li>a:focus {
    color: #fff;
    background-color: #006687;
}
.navbar-inverse .navbar-nav .open .dropdown-menu>.active>a, .navbar-inverse .navbar-nav .open .dropdown-menu>.active>a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu>.active>a:focus {
    color: #fff;
    background-color: #006687;
}
.navbar-inverse .navbar-nav .open .dropdown-menu>.disabled>a, .navbar-inverse .navbar-nav .open .dropdown-menu>.disabled>a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu>.disabled>a:focus {
    color: #444;
    background-color: transparent;
}
}.navbar-inverse .navbar-link {
    color: #fff;
}
.navbar-inverse .navbar-link:hover {
    color: #fff;
}
.breadcrumb {
    padding: 8px 15px;
    margin-bottom: 21px;
    list-style: none;
    background-color: #f5f5f5;
    border-radius: 0;
}
.breadcrumb>li {
    display: inline-block;
}
.breadcrumb>li+li:before {
    padding: 0 5px;
    color: #999;
    content: "/\00a0"}
.breadcrumb>.active {
    color: #333;
}
.pagination {
    display: inline-block;
    padding-left: 0;
    margin: 21px 0;
    border-radius: 0;
}
.pagination>li {
    display: inline;
}
.pagination>li>a, .pagination>li>span {
    position: relative;
    float: left;
    padding: 6px 12px;
    margin-left: -1px;
    line-height: 1.428571429;
    text-decoration: none;
    background-color: transparent;
    border: 1px solid transparent;
}
.pagination>li:first-child>a, .pagination>li:first-child>span {
    margin-left: 0;
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}
.pagination>li:last-child>a, .pagination>li:last-child>span {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}
.pagination>li>a:hover, .pagination>li>span:hover, .pagination>li>a:focus, .pagination>li>span:focus {
    background-color: #eee;
}
.pagination>.active>a, .pagination>.active>span, .pagination>.active>a:hover, .pagination>.active>span:hover, .pagination>.active>a:focus, .pagination>.active>span:focus {
    z-index: 2;
    color: #fff;
    cursor: default;
    background-color: #008cba;
    border-color: #008cba;
}
.pagination>.disabled>span, .pagination>.disabled>span:hover, .pagination>.disabled>span:focus, .pagination>.disabled>a, .pagination>.disabled>a:hover, .pagination>.disabled>a:focus {
    color: #999;
    cursor: not-allowed;
    background-color: transparent;
    border-color: transparent;
}
.pagination-lg>li>a, .pagination-lg>li>span {
    padding: 10px 16px;
    font-size: 19px;
}
.pagination-lg>li:first-child>a, .pagination-lg>li:first-child>span {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}
.pagination-lg>li:last-child>a, .pagination-lg>li:last-child>span {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}
.pagination-sm>li>a, .pagination-sm>li>span {
    padding: 5px 10px;
    font-size: 12px;
}
.pagination-sm>li:first-child>a, .pagination-sm>li:first-child>span {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
}
.pagination-sm>li:last-child>a, .pagination-sm>li:last-child>span {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}
.pager {
    padding-left: 0;
    margin: 21px 0;
    text-align: center;
    list-style: none;
}
.pager:before, .pager:after {
    display: table;
    content: " "}
.pager:after {
    clear: both;
}
.pager:before, .pager:after {
    display: table;
    content: " "}
.pager:after {
    clear: both;
}
.pager:before, .pager:after {
    display: table;
    content: " "}
.pager:after {
    clear: both;
}
.pager:before, .pager:after {
    display: table;
    content: " "}
.pager:after {
    clear: both;
}
.pager:before, .pager:after {
    display: table;
    content: " "}
.pager:after {
    clear: both;
}
.pager li {
    display: inline;
}
.pager li>a, .pager li>span {
    display: inline-block;
    padding: 5px 14px;
    background-color: transparent;
    border: 1px solid transparent;
    border-radius: 3px;
}
.pager li>a:hover, .pager li>a:focus {
    text-decoration: none;
    background-color: #eee;
}
.pager .next>a, .pager .next>span {
    float: right;
}
.pager .previous>a, .pager .previous>span {
    float: left;
}
.pager .disabled>a, .pager .disabled>a:hover, .pager .disabled>a:focus, .pager .disabled>span {
    color: #999;
    cursor: not-allowed;
    background-color: transparent;
}
.label {
    display: inline;
    padding: .2em .6em .3em;
    font-size: 75%;
    font-weight: bold;
    line-height: 1;
    color: #fff;
    text-align: center;
    white-space: nowrap;
    vertical-align: baseline;
    border-radius: .25em;
}
.label[href]:hover, .label[href]:focus {
    color: #fff;
    text-decoration: none;
    cursor: pointer;
}
.label:empty {
    display: none;
}
.btn .label {
    position: relative;
    top: -1px;
}
.label-default {
    background-color: #999;
}
.label-default[href]:hover, .label-default[href]:focus {
    background-color: #808080;
}
.label-primary {
    background-color: #008cba;
}
.label-primary[href]:hover, .label-primary[href]:focus {
    background-color: #006687;
}
.label-success {
    background-color: #43ac6a;
}
.label-success[href]:hover, .label-success[href]:focus {
    background-color: #358753;
}
.label-info {
    background-color: #5bc0de;
}
.label-info[href]:hover, .label-info[href]:focus {
    background-color: #31b0d5;
}
.label-warning {
    background-color: #e99002;
}
.label-warning[href]:hover, .label-warning[href]:focus {
    background-color: #b67102;
}
.label-danger {
    background-color: #f04124;
}
.label-danger[href]:hover, .label-danger[href]:focus {
    background-color: #d32a0e;
}
.badge {
    display: inline-block;
    min-width: 10px;
    padding: 3px 7px;
    font-size: 12px;
    font-weight: bold;
    line-height: 1;
    color: #777;
    text-align: center;
    white-space: nowrap;
    vertical-align: baseline;
    background-color: #e7e7e7;
    border-radius: 10px;
}
.badge:empty {
    display: none;
}
.btn .badge {
    position: relative;
    top: -1px;
}
a.badge:hover, a.badge:focus {
    color: #fff;
    text-decoration: none;
    cursor: pointer;
}
a.list-group-item.active>.badge, .nav-pills>.active>a>.badge {
    color: #008cba;
    background-color: #fff;
}
.nav-pills>li>a>.badge {
    margin-left: 3px;
}
.jumbotron {
    padding: 30px;
    margin-bottom: 30px;
    font-size: 23px;
    font-weight: 200;
    line-height: 2.1428571435;
    color: inherit;
    background-color: #fafafa;
}
.jumbotron h1, .jumbotron .h1 {
    line-height: 1;
    color: inherit;
}
.jumbotron p {
    line-height: 1.4;
}
.container .jumbotron {
    border-radius: 0;
}
.jumbotron .container {
    max-width: 100%}
@media screen and (min-width:768px) {
    .jumbotron {
    padding-top: 48px;
    padding-bottom: 48px;
}
.container .jumbotron {
    padding-right: 60px;
    padding-left: 60px;
}
.jumbotron h1, .jumbotron .h1 {
    font-size: 67.5px;
}
}.thumbnail {
    display: block;
    padding: 4px;
    margin-bottom: 21px;
    line-height: 1.428571429;
    background-color: #fff;
    border: 1px solid #ddd;
    border-radius: 0;
    -webkit-transition: all .2s ease-in-out;
    transition: all .2s ease-in-out;
}
.thumbnail>img, .thumbnail a>img {
    display: block;
    height: auto;
    max-width: 100%;
    margin-right: auto;
    margin-left: auto;
}
a.thumbnail:hover, a.thumbnail:focus, a.thumbnail.active {
    border-color: #008cba;
}
.thumbnail .caption {
    padding: 9px;
    color: #222;
}
.alert {
    position: relative;
    padding: 0.75rem 1.25rem;
    margin-bottom: 1rem;
    border: 1px solid transparent;
    border-radius: 0.25rem;
  }
  
  .alert-heading {
    color: inherit;
  }
  
  .alert-link {
    font-weight: 700;
  }
  
  .alert-dismissible {
    padding-right: 4rem;
  }
  
  .alert-dismissible .close {
    position: absolute;
    top: 0;
    right: 0;
    padding: 0.75rem 1.25rem;
    color: inherit;
  }
  
  .alert-primary {
    color: #004085;
    background-color: #cce5ff;
    border-color: #b8daff;
  }
  
  .alert-primary hr {
    border-top-color: #9fcdff;
  }
  
  .alert-primary .alert-link {
    color: #002752;
  }
  
  .alert-secondary {
    color: #383d41;
    background-color: #e2e3e5;
    border-color: #d6d8db;
  }
  
  .alert-secondary hr {
    border-top-color: #c8cbcf;
  }
  
  .alert-secondary .alert-link {
    color: #202326;
  }
  
  .alert-success {
    color: #155724;
    background-color: #d4edda;
    border-color: #c3e6cb;
  }
  
  .alert-success hr {
    border-top-color: #b1dfbb;
  }
  
  .alert-success .alert-link {
    color: #0b2e13;
  }
  
  .alert-info {
    color: #0c5460;
    background-color: #d1ecf1;
    border-color: #bee5eb;
  }
  
  .alert-info hr {
    border-top-color: #abdde5;
  }
  
  .alert-info .alert-link {
    color: #062c33;
  }
  
  .alert-warning {
    color: #856404;
    background-color: #fff3cd;
    border-color: #ffeeba;
  }
  
  .alert-warning hr {
    border-top-color: #ffe8a1;
  }
  
  .alert-warning .alert-link {
    color: #533f03;
  }
  
  .alert-danger {
    color: #721c24;
    background-color: #f8d7da;
    border-color: #f5c6cb;
  }
  
  .alert-danger hr {
    border-top-color: #f1b0b7;
  }
  
  .alert-danger .alert-link {
    color: #491217;
  }
  
  .alert-light {
    color: #818182;
    background-color: #fefefe;
    border-color: #fdfdfe;
  }
  
  .alert-light hr {
    border-top-color: #ececf6;
  }
  
  .alert-light .alert-link {
    color: #686868;
  }
  
  .alert-dark {
    color: #1b1e21;
    background-color: #d6d8d9;
    border-color: #c6c8ca;
  }
  
  .alert-dark hr {
    border-top-color: #b9bbbe;
  }
  
  .alert-dark .alert-link {
    color: #040505;
  }


@-webkit-keyframes progress-bar-stripes {
    from {
    background-position: 40px 0;
}
to {
    background-position: 0 0;
}
}@keyframes progress-bar-stripes {
    from {
    background-position: 40px 0;
}
to {
    background-position: 0 0;
}
}.progress {
    height: 21px;
    margin-bottom: 21px;
    overflow: hidden;
    background-color: #f5f5f5;
    border-radius: 0;
    -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
    box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
}
.progress-bar {
    float: left;
    width: 0;
    height: 100%;
    font-size: 12px;
    line-height: 21px;
    color: #fff;
    text-align: center;
    background-color: #008cba;
    -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
    box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
    -webkit-transition: width .6s ease;
    transition: width .6s ease;
}
.progress-striped .progress-bar {
    background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-size: 40px 40px;
}
.progress.active .progress-bar {
    -webkit-animation: progress-bar-stripes 2s linear infinite;
    animation: progress-bar-stripes 2s linear infinite;
}
.progress-bar-success {
    background-color: #43ac6a;
}
.progress-striped .progress-bar-success {
    background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-info {
    background-color: #5bc0de;
}
.progress-striped .progress-bar-info {
    background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-warning {
    background-color: #e99002;
}
.progress-striped .progress-bar-warning {
    background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.progress-bar-danger {
    background-color: #f04124;
}
.progress-striped .progress-bar-danger {
    background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}
.media, .media-body {
    overflow: hidden;
    zoom: 1;
}
.media, .media .media {
    margin-top: 15px;
}
.media:first-child {
    margin-top: 0;
}
.media-object {
    display: block;
}
.media-heading {
    margin: 0 0 5px;
}
.media>.pull-left {
    margin-right: 10px;
}
.media>.pull-right {
    margin-left: 10px;
}
.media-list {
    padding-left: 0;
    list-style: none;
}
.list-group {
    padding-left: 0;
    margin-bottom: 20px;
}
.list-group-item {
    position: relative;
    display: block;
    padding: 10px 15px;
    margin-bottom: -1px;
    background-color: #fff;
    border: 1px solid #ddd;
}
.list-group-item:first-child {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}
.list-group-item:last-child {
    margin-bottom: 0;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}
.list-group-item>.badge {
    float: right;
}
.list-group-item>.badge+.badge {
    margin-right: 5px;
}
a.list-group-item {
    color: #555;
}
a.list-group-item .list-group-item-heading {
    color: #333;
}
a.list-group-item:hover, a.list-group-item:focus {
    text-decoration: none;
    background-color: #f5f5f5;
}
a.list-group-item.active, a.list-group-item.active:hover, a.list-group-item.active:focus {
    z-index: 2;
    color: #fff;
    background-color: #008cba;
    border-color: #008cba;
}
a.list-group-item.active .list-group-item-heading, a.list-group-item.active:hover .list-group-item-heading, a.list-group-item.active:focus .list-group-item-heading {
    color: inherit;
}
a.list-group-item.active .list-group-item-text, a.list-group-item.active:hover .list-group-item-text, a.list-group-item.active:focus .list-group-item-text {
    color: #87e1ff;
}
.list-group-item-heading {
    margin-top: 0;
    margin-bottom: 5px;
}
.list-group-item-text {
    margin-bottom: 0;
    line-height: 1.3;
}
.panel {
    margin-bottom: 21px;
    background-color: #fff;
    border: 1px solid transparent;
    border-radius: 0;
    -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
}
.panel-body {
    padding: 15px;
}
.panel-body:before, .panel-body:after {
    display: table;
    content: " "}
.panel-body:after {
    clear: both;
}
.panel-body:before, .panel-body:after {
    display: table;
    content: " "}
.panel-body:after {
    clear: both;
}
.panel-body:before, .panel-body:after {
    display: table;
    content: " "}
.panel-body:after {
    clear: both;
}
.panel-body:before, .panel-body:after {
    display: table;
    content: " "}
.panel-body:after {
    clear: both;
}
.panel-body:before, .panel-body:after {
    display: table;
    content: " "}
.panel-body:after {
    clear: both;
}
.panel>.list-group {
    margin-bottom: 0;
}
.panel>.list-group .list-group-item {
    border-width: 1px 0;
}
.panel>.list-group .list-group-item:first-child {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}
.panel>.list-group .list-group-item:last-child {
    border-bottom: 0;
}
.panel-heading+.list-group .list-group-item:first-child {
    border-top-width: 0;
}
.panel>.table, .panel>.table-responsive>.table {
    margin-bottom: 0;
}
.panel>.panel-body+.table, .panel>.panel-body+.table-responsive {
    border-top: 1px solid #ddd;
}
.panel>.table>tbody:first-child th, .panel>.table>tbody:first-child td {
    border-top: 0;
}
.panel>.table-bordered, .panel>.table-responsive>.table-bordered {
    border: 0;
}
.panel>.table-bordered>thead>tr>th:first-child, .panel>.table-responsive>.table-bordered>thead>tr>th:first-child, .panel>.table-bordered>tbody>tr>th:first-child, .panel>.table-responsive>.table-bordered>tbody>tr>th:first-child, .panel>.table-bordered>tfoot>tr>th:first-child, .panel>.table-responsive>.table-bordered>tfoot>tr>th:first-child, .panel>.table-bordered>thead>tr>td:first-child, .panel>.table-responsive>.table-bordered>thead>tr>td:first-child, .panel>.table-bordered>tbody>tr>td:first-child, .panel>.table-responsive>.table-bordered>tbody>tr>td:first-child, .panel>.table-bordered>tfoot>tr>td:first-child, .panel>.table-responsive>.table-bordered>tfoot>tr>td:first-child {
    border-left: 0;
}
.panel>.table-bordered>thead>tr>th:last-child, .panel>.table-responsive>.table-bordered>thead>tr>th:last-child, .panel>.table-bordered>tbody>tr>th:last-child, .panel>.table-responsive>.table-bordered>tbody>tr>th:last-child, .panel>.table-bordered>tfoot>tr>th:last-child, .panel>.table-responsive>.table-bordered>tfoot>tr>th:last-child, .panel>.table-bordered>thead>tr>td:last-child, .panel>.table-responsive>.table-bordered>thead>tr>td:last-child, .panel>.table-bordered>tbody>tr>td:last-child, .panel>.table-responsive>.table-bordered>tbody>tr>td:last-child, .panel>.table-bordered>tfoot>tr>td:last-child, .panel>.table-responsive>.table-bordered>tfoot>tr>td:last-child {
    border-right: 0;
}
.panel>.table-bordered>thead>tr:last-child>th, .panel>.table-responsive>.table-bordered>thead>tr:last-child>th, .panel>.table-bordered>tbody>tr:last-child>th, .panel>.table-responsive>.table-bordered>tbody>tr:last-child>th, .panel>.table-bordered>tfoot>tr:last-child>th, .panel>.table-responsive>.table-bordered>tfoot>tr:last-child>th, .panel>.table-bordered>thead>tr:last-child>td, .panel>.table-responsive>.table-bordered>thead>tr:last-child>td, .panel>.table-bordered>tbody>tr:last-child>td, .panel>.table-responsive>.table-bordered>tbody>tr:last-child>td, .panel>.table-bordered>tfoot>tr:last-child>td, .panel>.table-responsive>.table-bordered>tfoot>tr:last-child>td {
    border-bottom: 0;
}
.panel>.table-responsive {
    margin-bottom: 0;
    border: 0;
}
.panel-heading {
    padding: 10px 15px;
    border-bottom: 1px solid transparent;
    border-top-right-radius: -1;
    border-top-left-radius: -1;
}
.panel-heading>.dropdown .dropdown-toggle {
    color: inherit;
}
.panel-title {
    margin-top: 0;
    margin-bottom: 0;
    font-size: 17px;
    color: inherit;
}
.panel-title>a {
    color: inherit;
}
.panel-footer {
    padding: 10px 15px;
    background-color: #f5f5f5;
    border-top: 1px solid #ddd;
    border-bottom-right-radius: -1;
    border-bottom-left-radius: -1;
}
.panel-group .panel {
    margin-bottom: 0;
    overflow: hidden;
    border-radius: 0;
}
.panel-group .panel+.panel {
    margin-top: 5px;
}
.panel-group .panel-heading {
    border-bottom: 0;
}
.panel-group .panel-heading+.panel-collapse .panel-body {
    border-top: 1px solid #ddd;
}
.panel-group .panel-footer {
    border-top: 0;
}
.panel-group .panel-footer+.panel-collapse .panel-body {
    border-bottom: 1px solid #ddd;
}
.panel-default {
    border-color: #ddd;
}
.panel-default>.panel-heading {
    color: #333;
    background-color: #f5f5f5;
    border-color: #ddd;
}
.panel-default>.panel-heading+.panel-collapse .panel-body {
    border-top-color: #ddd;
}
.panel-default>.panel-footer+.panel-collapse .panel-body {
    border-bottom-color: #ddd;
}
.panel-primary {
    border-color: #008cba;
}
.panel-primary>.panel-heading {
    color: #fff;
    background-color: #008cba;
    border-color: #008cba;
}
.panel-primary>.panel-heading+.panel-collapse .panel-body {
    border-top-color: #008cba;
}
.panel-primary>.panel-footer+.panel-collapse .panel-body {
    border-bottom-color: #008cba;
}
.panel-success {
    border-color: #3c9a5f;
}
.panel-success>.panel-heading {
    color: #43ac6a;
    background-color: #dff0d8;
    border-color: #3c9a5f;
}
.panel-success>.panel-heading+.panel-collapse .panel-body {
    border-top-color: #3c9a5f;
}
.panel-success>.panel-footer+.panel-collapse .panel-body {
    border-bottom-color: #3c9a5f;
}
.panel-warning {
    border-color: #d08002;
}
.panel-warning>.panel-heading {
    color: #e99002;
    background-color: #fcf8e3;
    border-color: #d08002;
}
.panel-warning>.panel-heading+.panel-collapse .panel-body {
    border-top-color: #d08002;
}
.panel-warning>.panel-footer+.panel-collapse .panel-body {
    border-bottom-color: #d08002;
}
.panel-danger {
    border-color: #ea2f10;
}
.panel-danger>.panel-heading {
    color: #f04124;
    background-color: #f2dede;
    border-color: #ea2f10;
}
.panel-danger>.panel-heading+.panel-collapse .panel-body {
    border-top-color: #ea2f10;
}
.panel-danger>.panel-footer+.panel-collapse .panel-body {
    border-bottom-color: #ea2f10;
}
.panel-info {
    border-color: #3db5d8;
}
.panel-info>.panel-heading {
    color: #5bc0de;
    background-color: #d9edf7;
    border-color: #3db5d8;
}
.panel-info>.panel-heading+.panel-collapse .panel-body {
    border-top-color: #3db5d8;
}
.panel-info>.panel-footer+.panel-collapse .panel-body {
    border-bottom-color: #3db5d8;
}
.well {
    min-height: 20px;
    padding: 19px;
    margin-bottom: 20px;
    background-color: #fafafa;
    border: 1px solid #e8e8e8;
    border-radius: 0;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
}
.well blockquote {
    border-color: #ddd;
    border-color: rgba(0, 0, 0, 0.15);
}
.well-lg {
    padding: 24px;
    border-radius: 0;
}
.well-sm {
    padding: 9px;
    border-radius: 0;
}
.close {
    float: right;
    font-size: 22.5px;
    font-weight: bold;
    line-height: 1;
    color: #000;
    text-shadow: 0 1px 0 #fff;
    opacity: .2;
    filter: alpha(opacity=20);
}
.close:hover, .close:focus {
    color: #000;
    text-decoration: none;
    cursor: pointer;
    opacity: .5;
    filter: alpha(opacity=50);
}
button.close {
    padding: 0;
    cursor: pointer;
    background: transparent;
    border: 0;
    -webkit-appearance: none;
}
.modal-open {
    overflow: hidden;
}
.modal {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1040;
    display: none;
    overflow: auto;
    overflow-y: scroll;
}
.modal.fade .modal-dialog {
    -webkit-transform: translate(0, -25%);
    -ms-transform: translate(0, -25%);
    transform: translate(0, -25%);
    -webkit-transition: -webkit-transform .3s ease-out;
    -moz-transition: -moz-transform .3s ease-out;
    -o-transition: -o-transform .3s ease-out;
    transition: transform .3s ease-out;
}
.modal.in .modal-dialog {
    -webkit-transform: translate(0, 0);
    -ms-transform: translate(0, 0);
    transform: translate(0, 0);
}
.modal-dialog {
    position: relative;
    z-index: 1050;
    width: auto;
    margin: 10px;
}
.modal-content {
    position: relative;
    background-color: #fff;
    border: 1px solid #999;
    border: 1px solid rgba(0, 0, 0, 0.2);
    border-radius: 0;
    outline: 0;
    -webkit-box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
    box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
    background-clip: padding-box;
}
.modal-backdrop {
    position: fixed;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    z-index: 1030;
    background-color: #000;
}
.modal-backdrop.fade {
    opacity: 0;
    filter: alpha(opacity=0);
}
.modal-backdrop.in {
    opacity: .5;
    filter: alpha(opacity=50);
}
.modal-header {
    min-height: 16.428571429px;
    padding: 15px;
    border-bottom: 1px solid #e5e5e5;
}
.modal-header .close {
    margin-top: -2px;
}
.modal-title {
    margin: 0;
    line-height: 1.428571429;
}
.modal-body {
    position: relative;
    padding: 20px;
}
.modal-footer {
    padding: 19px 20px 20px;
    margin-top: 15px;
    text-align: right;
    border-top: 1px solid #e5e5e5;
}
.modal-footer:before, .modal-footer:after {
    display: table;
    content: " "}
.modal-footer:after {
    clear: both;
}
.modal-footer:before, .modal-footer:after {
    display: table;
    content: " "}
.modal-footer:after {
    clear: both;
}
.modal-footer:before, .modal-footer:after {
    display: table;
    content: " "}
.modal-footer:after {
    clear: both;
}
.modal-footer:before, .modal-footer:after {
    display: table;
    content: " "}
.modal-footer:after {
    clear: both;
}
.modal-footer:before, .modal-footer:after {
    display: table;
    content: " "}
.modal-footer:after {
    clear: both;
}
.modal-footer .btn+.btn {
    margin-bottom: 0;
    margin-left: 5px;
}
.modal-footer .btn-group .btn+.btn {
    margin-left: -1px;
}
.modal-footer .btn-block+.btn-block {
    margin-left: 0;
}
@media screen and (min-width:768px) {
    .modal-dialog {
    width: 600px;
    margin: 30px auto;
}
.modal-content {
    -webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
    box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
}
}.tooltip {
    position: absolute;
    z-index: 1030;
    display: block;
    font-size: 12px;
    line-height: 1.4;
    opacity: 0;
    filter: alpha(opacity=0);
    visibility: visible;
}
.tooltip.in {
    opacity: .9;
    filter: alpha(opacity=90);
}
.tooltip.top {
    padding: 5px 0;
    margin-top: -3px;
}
.tooltip.right {
    padding: 0 5px;
    margin-left: 3px;
}
.tooltip.bottom {
    padding: 5px 0;
    margin-top: 3px;
}
.tooltip.left {
    padding: 0 5px;
    margin-left: -3px;
}
.tooltip-inner {
    max-width: 200px;
    padding: 3px 8px;
    color: #fff;
    text-align: center;
    text-decoration: none;
    background-color: #333;
    border-radius: 0;
}
.tooltip-arrow {
    position: absolute;
    width: 0;
    height: 0;
    border-color: transparent;
    border-style: solid;
}
.tooltip.top .tooltip-arrow {
    bottom: 0;
    left: 50%;
    margin-left: -5px;
    border-top-color: #333;
    border-width: 5px 5px 0;
}
.tooltip.top-left .tooltip-arrow {
    bottom: 0;
    left: 5px;
    border-top-color: #333;
    border-width: 5px 5px 0;
}
.tooltip.top-right .tooltip-arrow {
    right: 5px;
    bottom: 0;
    border-top-color: #333;
    border-width: 5px 5px 0;
}
.tooltip.right .tooltip-arrow {
    top: 50%;
    left: 0;
    margin-top: -5px;
    border-right-color: #333;
    border-width: 5px 5px 5px 0;
}
.tooltip.left .tooltip-arrow {
    top: 50%;
    right: 0;
    margin-top: -5px;
    border-left-color: #333;
    border-width: 5px 0 5px 5px;
}
.tooltip.bottom .tooltip-arrow {
    top: 0;
    left: 50%;
    margin-left: -5px;
    border-bottom-color: #333;
    border-width: 0 5px 5px;
}
.tooltip.bottom-left .tooltip-arrow {
    top: 0;
    left: 5px;
    border-bottom-color: #333;
    border-width: 0 5px 5px;
}
.tooltip.bottom-right .tooltip-arrow {
    top: 0;
    right: 5px;
    border-bottom-color: #333;
    border-width: 0 5px 5px;
}
.popover {
    position: absolute;
    top: 0;
    left: 0;
    z-index: 1010;
    display: none;
    max-width: 276px;
    padding: 1px;
    text-align: left;
    white-space: normal;
    background-color: #333;
    border: 1px solid #333;
    border: 1px solid transparent;
    border-radius: 0;
    -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
    box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
    background-clip: padding-box;
}
.popover.top {
    margin-top: -10px;
}
.popover.right {
    margin-left: 10px;
}
.popover.bottom {
    margin-top: 10px;
}
.popover.left {
    margin-left: -10px;
}
.popover-title {
    padding: 8px 14px;
    margin: 0;
    font-size: 15px;
    font-weight: normal;
    line-height: 18px;
    background-color: #333;
    border-bottom: 1px solid #262626;
    border-radius: 5px 5px 0 0;
}
.popover-content {
    padding: 9px 14px;
}
.popover .arrow, .popover .arrow:after {
    position: absolute;
    display: block;
    width: 0;
    height: 0;
    border-color: transparent;
    border-style: solid;
}
.popover .arrow {
    border-width: 11px;
}
.popover .arrow:after {
    border-width: 10px;
    content: ""}
.popover.top .arrow {
    bottom: -11px;
    left: 50%;
    margin-left: -11px;
    border-top-color: #999;
    border-top-color: rgba(0, 0, 0, 0.25);
    border-bottom-width: 0;
}
.popover.top .arrow:after {
    bottom: 1px;
    margin-left: -10px;
    border-top-color: #333;
    border-bottom-width: 0;
    content: " "}
.popover.right .arrow {
    top: 50%;
    left: -11px;
    margin-top: -11px;
    border-right-color: #999;
    border-right-color: rgba(0, 0, 0, 0.25);
    border-left-width: 0;
}
.popover.right .arrow:after {
    bottom: -10px;
    left: 1px;
    border-right-color: #333;
    border-left-width: 0;
    content: " "}
.popover.bottom .arrow {
    top: -11px;
    left: 50%;
    margin-left: -11px;
    border-bottom-color: #999;
    border-bottom-color: rgba(0, 0, 0, 0.25);
    border-top-width: 0;
}
.popover.bottom .arrow:after {
    top: 1px;
    margin-left: -10px;
    border-bottom-color: #333;
    border-top-width: 0;
    content: " "}
.popover.left .arrow {
    top: 50%;
    right: -11px;
    margin-top: -11px;
    border-left-color: #999;
    border-left-color: rgba(0, 0, 0, 0.25);
    border-right-width: 0;
}
.popover.left .arrow:after {
    right: 1px;
    bottom: -10px;
    border-left-color: #333;
    border-right-width: 0;
    content: " "}
.carousel {
    position: relative;
}
.carousel-inner {
    position: relative;
    width: 100%;
    overflow: hidden;
}
.carousel-inner>.item {
    position: relative;
    display: none;
    -webkit-transition: .6s ease-in-out left;
    transition: .6s ease-in-out left;
}
.carousel-inner>.item>img, .carousel-inner>.item>a>img {
    display: block;
    height: auto;
    max-width: 100%;
    line-height: 1;
}
.carousel-inner>.active, .carousel-inner>.next, .carousel-inner>.prev {
    display: block;
}
.carousel-inner>.active {
    left: 0;
}
.carousel-inner>.next, .carousel-inner>.prev {
    position: absolute;
    top: 0;
    width: 100%}
.carousel-inner>.next {
    left: 100%}
.carousel-inner>.prev {
    left: -100%}
.carousel-inner>.next.left, .carousel-inner>.prev.right {
    left: 0;
}
.carousel-inner>.active.left {
    left: -100%}
.carousel-inner>.active.right {
    left: 100%}
.carousel-control {
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    width: 15%;
    font-size: 20px;
    color: #fff;
    text-align: center;
    text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
    opacity: .5;
    filter: alpha(opacity=50);
}
.carousel-control.left {
    background-image: -webkit-linear-gradient(left, color-stop(rgba(0, 0, 0, 0.5) 0), color-stop(rgba(0, 0, 0, 0.0001) 100%));
    background-image: linear-gradient(to right, rgba(0, 0, 0, 0.5) 0, rgba(0, 0, 0, 0.0001) 100%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#80000000', endColorstr='#00000000', GradientType=1);
}
.carousel-control.right {
    right: 0;
    left: auto;
    background-image: -webkit-linear-gradient(left, color-stop(rgba(0, 0, 0, 0.0001) 0), color-stop(rgba(0, 0, 0, 0.5) 100%));
    background-image: linear-gradient(to right, rgba(0, 0, 0, 0.0001) 0, rgba(0, 0, 0, 0.5) 100%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#80000000', GradientType=1);
}
.carousel-control:hover, .carousel-control:focus {
    color: #fff;
    text-decoration: none;
    outline: 0;
    opacity: .9;
    filter: alpha(opacity=90);
}
.carousel-control .icon-prev, .carousel-control .icon-next, .carousel-control .glyphicon-chevron-left, .carousel-control .glyphicon-chevron-right {
    position: absolute;
    top: 50%;
    z-index: 5;
    display: inline-block;
}
.carousel-control .icon-prev, .carousel-control .glyphicon-chevron-left {
    left: 50%}
.carousel-control .icon-next, .carousel-control .glyphicon-chevron-right {
    right: 50%}
.carousel-control .icon-prev, .carousel-control .icon-next {
    width: 20px;
    height: 20px;
    margin-top: -10px;
    margin-left: -10px;
    font-family: serif;
}
.carousel-control .icon-prev:before {
    content: '\2039'}
.carousel-control .icon-next:before {
    content: '\203a'}
.carousel-indicators {
    position: absolute;
    bottom: 10px;
    left: 50%;
    z-index: 15;
    width: 60%;
    padding-left: 0;
    margin-left: -30%;
    text-align: center;
    list-style: none;
}
.carousel-indicators li {
    display: inline-block;
    width: 10px;
    height: 10px;
    margin: 1px;
    text-indent: -999px;
    cursor: pointer;
    background-color: #000 \9;
    background-color: rgba(0, 0, 0, 0);
    border: 1px solid #fff;
    border-radius: 10px;
}
.carousel-indicators .active {
    width: 12px;
    height: 12px;
    margin: 0;
    background-color: #fff;
}
.carousel-caption {
    position: absolute;
    right: 15%;
    bottom: 20px;
    left: 15%;
    z-index: 10;
    padding-top: 20px;
    padding-bottom: 20px;
    color: #fff;
    text-align: center;
    text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
}
.carousel-caption .btn {
    text-shadow: none;
}
@media screen and (min-width:768px) {
    .carousel-control .glyphicons-chevron-left, .carousel-control .glyphicons-chevron-right, .carousel-control .icon-prev, .carousel-control .icon-next {
    width: 30px;
    height: 30px;
    margin-top: -15px;
    margin-left: -15px;
    font-size: 30px;
}
.carousel-caption {
    right: 20%;
    left: 20%;
    padding-bottom: 30px;
}
.carousel-indicators {
    bottom: 20px;
}
}.clearfix:before, .clearfix:after {
    display: table;
    content: " "}
.clearfix:after {
    clear: both;
}
.clearfix:before, .clearfix:after {
    display: table;
    content: " "}
.clearfix:after {
    clear: both;
}
.center-block {
    display: block;
    margin-right: auto;
    margin-left: auto;
}
.pull-right {
    float: right!important;
}
.pull-left {
    float: left!important;
}
.hide {
    display: none!important;
}
.show {
    display: block!important;
}
.invisible {
    visibility: hidden;
}
.text-hide {
    font: 0/0 a;
    color: transparent;
    text-shadow: none;
    background-color: transparent;
    border: 0;
}
.hidden {
    display: none!important;
    visibility: hidden!important;
}
.affix {
    position: fixed;
}
@-ms-viewport {
    width: device-width;
}
.visible-xs, tr.visible-xs, th.visible-xs, td.visible-xs {
    display: none!important;
}
@media(max-width:767px) {
    .visible-xs {
    display: block!important;
}
table.visible-xs {
    display: table;
}
tr.visible-xs {
    display: table-row!important;
}
th.visible-xs, td.visible-xs {
    display: table-cell!important;
}
}@media(min-width:768px) and (max-width:991px) {
    .visible-xs.visible-sm {
    display: block!important;
}
table.visible-xs.visible-sm {
    display: table;
}
tr.visible-xs.visible-sm {
    display: table-row!important;
}
th.visible-xs.visible-sm, td.visible-xs.visible-sm {
    display: table-cell!important;
}
}@media(min-width:992px) and (max-width:1199px) {
    .visible-xs.visible-md {
    display: block!important;
}
table.visible-xs.visible-md {
    display: table;
}
tr.visible-xs.visible-md {
    display: table-row!important;
}
th.visible-xs.visible-md, td.visible-xs.visible-md {
    display: table-cell!important;
}
}@media(min-width:1200px) {
    .visible-xs.visible-lg {
    display: block!important;
}
table.visible-xs.visible-lg {
    display: table;
}
tr.visible-xs.visible-lg {
    display: table-row!important;
}
th.visible-xs.visible-lg, td.visible-xs.visible-lg {
    display: table-cell!important;
}
}.visible-sm, tr.visible-sm, th.visible-sm, td.visible-sm {
    display: none!important;
}
@media(max-width:767px) {
    .visible-sm.visible-xs {
    display: block!important;
}
table.visible-sm.visible-xs {
    display: table;
}
tr.visible-sm.visible-xs {
    display: table-row!important;
}
th.visible-sm.visible-xs, td.visible-sm.visible-xs {
    display: table-cell!important;
}
}@media(min-width:768px) and (max-width:991px) {
    .visible-sm {
    display: block!important;
}
table.visible-sm {
    display: table;
}
tr.visible-sm {
    display: table-row!important;
}
th.visible-sm, td.visible-sm {
    display: table-cell!important;
}
}@media(min-width:992px) and (max-width:1199px) {
    .visible-sm.visible-md {
    display: block!important;
}
table.visible-sm.visible-md {
    display: table;
}
tr.visible-sm.visible-md {
    display: table-row!important;
}
th.visible-sm.visible-md, td.visible-sm.visible-md {
    display: table-cell!important;
}
}@media(min-width:1200px) {
    .visible-sm.visible-lg {
    display: block!important;
}
table.visible-sm.visible-lg {
    display: table;
}
tr.visible-sm.visible-lg {
    display: table-row!important;
}
th.visible-sm.visible-lg, td.visible-sm.visible-lg {
    display: table-cell!important;
}
}.visible-md, tr.visible-md, th.visible-md, td.visible-md {
    display: none!important;
}
@media(max-width:767px) {
    .visible-md.visible-xs {
    display: block!important;
}
table.visible-md.visible-xs {
    display: table;
}
tr.visible-md.visible-xs {
    display: table-row!important;
}
th.visible-md.visible-xs, td.visible-md.visible-xs {
    display: table-cell!important;
}
}@media(min-width:768px) and (max-width:991px) {
    .visible-md.visible-sm {
    display: block!important;
}
table.visible-md.visible-sm {
    display: table;
}
tr.visible-md.visible-sm {
    display: table-row!important;
}
th.visible-md.visible-sm, td.visible-md.visible-sm {
    display: table-cell!important;
}
}@media(min-width:992px) and (max-width:1199px) {
    .visible-md {
    display: block!important;
}
table.visible-md {
    display: table;
}
tr.visible-md {
    display: table-row!important;
}
th.visible-md, td.visible-md {
    display: table-cell!important;
}
}@media(min-width:1200px) {
    .visible-md.visible-lg {
    display: block!important;
}
table.visible-md.visible-lg {
    display: table;
}
tr.visible-md.visible-lg {
    display: table-row!important;
}
th.visible-md.visible-lg, td.visible-md.visible-lg {
    display: table-cell!important;
}
}.visible-lg, tr.visible-lg, th.visible-lg, td.visible-lg {
    display: none!important;
}
@media(max-width:767px) {
    .visible-lg.visible-xs {
    display: block!important;
}
table.visible-lg.visible-xs {
    display: table;
}
tr.visible-lg.visible-xs {
    display: table-row!important;
}
th.visible-lg.visible-xs, td.visible-lg.visible-xs {
    display: table-cell!important;
}
}@media(min-width:768px) and (max-width:991px) {
    .visible-lg.visible-sm {
    display: block!important;
}
table.visible-lg.visible-sm {
    display: table;
}
tr.visible-lg.visible-sm {
    display: table-row!important;
}
th.visible-lg.visible-sm, td.visible-lg.visible-sm {
    display: table-cell!important;
}
}@media(min-width:992px) and (max-width:1199px) {
    .visible-lg.visible-md {
    display: block!important;
}
table.visible-lg.visible-md {
    display: table;
}
tr.visible-lg.visible-md {
    display: table-row!important;
}
th.visible-lg.visible-md, td.visible-lg.visible-md {
    display: table-cell!important;
}
}@media(min-width:1200px) {
    .visible-lg {
    display: block!important;
}
table.visible-lg {
    display: table;
}
tr.visible-lg {
    display: table-row!important;
}
th.visible-lg, td.visible-lg {
    display: table-cell!important;
}
}.hidden-xs {
    display: block!important;
}
table.hidden-xs {
    display: table;
}
tr.hidden-xs {
    display: table-row!important;
}
th.hidden-xs, td.hidden-xs {
    display: table-cell!important;
}
@media(max-width:767px) {
    .hidden-xs, tr.hidden-xs, th.hidden-xs, td.hidden-xs {
    display: none!important;
}
}@media(min-width:768px) and (max-width:991px) {
    .hidden-xs.hidden-sm, tr.hidden-xs.hidden-sm, th.hidden-xs.hidden-sm, td.hidden-xs.hidden-sm {
    display: none!important;
}
}@media(min-width:992px) and (max-width:1199px) {
    .hidden-xs.hidden-md, tr.hidden-xs.hidden-md, th.hidden-xs.hidden-md, td.hidden-xs.hidden-md {
    display: none!important;
}
}@media(min-width:1200px) {
    .hidden-xs.hidden-lg, tr.hidden-xs.hidden-lg, th.hidden-xs.hidden-lg, td.hidden-xs.hidden-lg {
    display: none!important;
}
}.hidden-sm {
    display: block!important;
}
table.hidden-sm {
    display: table;
}
tr.hidden-sm {
    display: table-row!important;
}
th.hidden-sm, td.hidden-sm {
    display: table-cell!important;
}
@media(max-width:767px) {
    .hidden-sm.hidden-xs, tr.hidden-sm.hidden-xs, th.hidden-sm.hidden-xs, td.hidden-sm.hidden-xs {
    display: none!important;
}
}@media(min-width:768px) and (max-width:991px) {
    .hidden-sm, tr.hidden-sm, th.hidden-sm, td.hidden-sm {
    display: none!important;
}
}@media(min-width:992px) and (max-width:1199px) {
    .hidden-sm.hidden-md, tr.hidden-sm.hidden-md, th.hidden-sm.hidden-md, td.hidden-sm.hidden-md {
    display: none!important;
}
}@media(min-width:1200px) {
    .hidden-sm.hidden-lg, tr.hidden-sm.hidden-lg, th.hidden-sm.hidden-lg, td.hidden-sm.hidden-lg {
    display: none!important;
}
}.hidden-md {
    display: block!important;
}
table.hidden-md {
    display: table;
}
tr.hidden-md {
    display: table-row!important;
}
th.hidden-md, td.hidden-md {
    display: table-cell!important;
}
@media(max-width:767px) {
    .hidden-md.hidden-xs, tr.hidden-md.hidden-xs, th.hidden-md.hidden-xs, td.hidden-md.hidden-xs {
    display: none!important;
}
}@media(min-width:768px) and (max-width:991px) {
    .hidden-md.hidden-sm, tr.hidden-md.hidden-sm, th.hidden-md.hidden-sm, td.hidden-md.hidden-sm {
    display: none!important;
}
}@media(min-width:992px) and (max-width:1199px) {
    .hidden-md, tr.hidden-md, th.hidden-md, td.hidden-md {
    display: none!important;
}
}@media(min-width:1200px) {
    .hidden-md.hidden-lg, tr.hidden-md.hidden-lg, th.hidden-md.hidden-lg, td.hidden-md.hidden-lg {
    display: none!important;
}
}.hidden-lg {
    display: block!important;
}
table.hidden-lg {
    display: table;
}
tr.hidden-lg {
    display: table-row!important;
}
th.hidden-lg, td.hidden-lg {
    display: table-cell!important;
}
@media(max-width:767px) {
    .hidden-lg.hidden-xs, tr.hidden-lg.hidden-xs, th.hidden-lg.hidden-xs, td.hidden-lg.hidden-xs {
    display: none!important;
}
}@media(min-width:768px) and (max-width:991px) {
    .hidden-lg.hidden-sm, tr.hidden-lg.hidden-sm, th.hidden-lg.hidden-sm, td.hidden-lg.hidden-sm {
    display: none!important;
}
}@media(min-width:992px) and (max-width:1199px) {
    .hidden-lg.hidden-md, tr.hidden-lg.hidden-md, th.hidden-lg.hidden-md, td.hidden-lg.hidden-md {
    display: none!important;
}
}@media(min-width:1200px) {
    .hidden-lg, tr.hidden-lg, th.hidden-lg, td.hidden-lg {
    display: none!important;
}
}.visible-print, tr.visible-print, th.visible-print, td.visible-print {
    display: none!important;
}
@media print {
    .visible-print {
    display: block!important;
}
table.visible-print {
    display: table;
}
tr.visible-print {
    display: table-row!important;
}
th.visible-print, td.visible-print {
    display: table-cell!important;
}
.hidden-print, tr.hidden-print, th.hidden-print, td.hidden-print {
    display: none!important;
}
}.navbar {
    font-size: 13px;
    font-weight: 300;
    border: 0;
}
.navbar .navbar-toggle:hover .icon-bar {
    background-color: #b3b3b3;
}
.navbar-collapse {
    border-top-color: rgba(0, 0, 0, 0.2);
    -webkit-box-shadow: none;
    box-shadow: none;
}
.navbar .dropdown-menu {
    border: 0;
}
.navbar .dropdown-menu>li>a, .navbar .dropdown-menu>li>a:focus {
    font-size: 13px;
    font-weight: 300;
    background-color: transparent;
}
.navbar .dropdown-header {
    color: rgba(255, 255, 255, 0.5);
}
.navbar-default .dropdown-menu {
    background-color: #333;
}
.navbar-default .dropdown-menu>li>a, .navbar-default .dropdown-menu>li>a:focus {
    color: #fff;
}
.navbar-default .dropdown-menu>li>a:hover, .navbar-default .dropdown-menu>.active>a, .navbar-default .dropdown-menu>.active>a:hover {
    background-color: #272727;
}
.navbar-inverse .dropdown-menu {
    background-color: #008cba;
}
.navbar-inverse .dropdown-menu>li>a, .navbar-inverse .dropdown-menu>li>a:focus {
    color: #fff;
}
.navbar-inverse .dropdown-menu>li>a:hover, .navbar-inverse .dropdown-menu>.active>a, .navbar-inverse .dropdown-menu>.active>a:hover {
    background-color: #006687;
}
.btn {
    padding: 14px 28px;
}
.btn-lg {
    padding: 16px 32px;
}
.btn-sm {
    padding: 8px 16px;
}
.btn-xs {
    padding: 4px 8px;
}
.btn-group .btn~.dropdown-toggle {
    padding-right: 16px;
    padding-left: 16px;
}
.btn-group .dropdown-menu {
    border-top-width: 0;
}
.btn-group.dropup .dropdown-menu {
    margin-bottom: 0;
    border-top-width: 1px;
    border-bottom-width: 0;
}
.btn-group .dropdown-toggle.btn-default~.dropdown-menu {
    background-color: #e7e7e7;
    border-color: #dadada;
}
.btn-group .dropdown-toggle.btn-default~.dropdown-menu>li>a {
    color: #333;
}
.btn-group .dropdown-toggle.btn-default~.dropdown-menu>li>a:hover {
    background-color: #d3d3d3;
}
.btn-group .dropdown-toggle.btn-primary~.dropdown-menu {
    background-color: #008cba;
    border-color: #0079a1;
}
.btn-group .dropdown-toggle.btn-primary~.dropdown-menu>li>a {
    color: #fff;
}
.btn-group .dropdown-toggle.btn-primary~.dropdown-menu>li>a:hover {
    background-color: #006d91;
}
.btn-group .dropdown-toggle.btn-success~.dropdown-menu {
    background-color: #43ac6a;
    border-color: #3c9a5f;
}
.btn-group .dropdown-toggle.btn-success~.dropdown-menu>li>a {
    color: #fff;
}
.btn-group .dropdown-toggle.btn-success~.dropdown-menu>li>a:hover {
    background-color: #388f58;
}
.btn-group .dropdown-toggle.btn-info~.dropdown-menu {
    background-color: #5bc0de;
    border-color: #46b8da;
}
.btn-group .dropdown-toggle.btn-info~.dropdown-menu>li>a {
    color: #fff;
}
.btn-group .dropdown-toggle.btn-info~.dropdown-menu>li>a:hover {
    background-color: #39b3d7;
}
.btn-group .dropdown-toggle.btn-warning~.dropdown-menu {
    background-color: #e99002;
    border-color: #d08002;
}
.btn-group .dropdown-toggle.btn-warning~.dropdown-menu>li>a {
    color: #fff;
}
.btn-group .dropdown-toggle.btn-warning~.dropdown-menu>li>a:hover {
    background-color: #c17702;
}
.btn-group .dropdown-toggle.btn-danger~.dropdown-menu {
    background-color: #f04124;
    border-color: #ea2f10;
}
.btn-group .dropdown-toggle.btn-danger~.dropdown-menu>li>a {
    color: #fff;
}
.btn-group .dropdown-toggle.btn-danger~.dropdown-menu>li>a:hover {
    background-color: #dc2c0f;
}
.lead {
    color: #6f6f6f;
}
cite {
    font-style: italic;
}
blockquote {
    color: #6f6f6f;
    border-left-width: 1px;
}
blockquote.pull-right {
    border-right-width: 1px;
}
blockquote small {
    font-size: 12px;
    font-weight: 300;
}
table {
    font-size: 12px;
}
input, .form-control {
    padding: 7px;
    font-size: 12px;
}
label, .control-label, .help-block, .checkbox, .radio {
    font-size: 12px;
    font-weight: normal;
}
.form-group .btn, .input-group-addon, .input-group-btn .btn {
    padding: 8px 14px;
    font-size: 12px;
}
.nav .open>a, .nav .open>a:hover, .nav .open>a:focus {
    border-color: transparent;
}
.nav-tabs>li>a {
    color: #222;
    background-color: #e7e7e7;
}
.nav-tabs .caret {
    border-top-color: #222;
    border-bottom-color: #222;
}
.nav-pills {
    font-weight: 300;
}
.breadcrumb {
    font-size: 10px;
    font-weight: 300;
    text-transform: uppercase;
    border: 1px solid #ddd;
    border-radius: 3px;
}
.pagination {
    font-size: 12px;
    font-weight: 300;
    color: #999;
}
.pagination>li>a, .pagination>li>span {
    margin-left: 4px;
    color: #999;
}
.pagination>.active>a, .pagination>.active>span {
    color: #fff;
}
.pagination>li>a, .pagination>li:first-child>a, .pagination>li:last-child>a, .pagination>li>span, .pagination>li:first-child>span, .pagination>li:last-child>span {
    border-radius: 3px;
}
.pagination-lg>li>a {
    padding-right: 22px;
    padding-left: 22px;
}
.pagination-sm>li>a {
    padding: 0 5px;
}
.pager {
    font-size: 12px;
    font-weight: 300;
    color: #999;
}
.list-group {
    font-size: 12px;
    font-weight: 300;
}
.label {
    padding-right: 1em;
    padding-left: 1em;
    font-weight: 300;
    border-radius: 0;
}
.label-default {
    color: #333;
    background-color: #e7e7e7;
}
.badge {
    font-weight: 300;
}
.progress {
    height: 22px;
    padding: 2px;
    background-color: #f6f6f6;
    border: 1px solid #ccc;
    -webkit-box-shadow: none;
    box-shadow: none;
}
.dropdown-menu {
    padding: 0;
    margin-top: 0;
    font-size: 12px;
}
.dropdown-menu>li>a {
    padding: 12px 15px;
}
.dropdown-header {
    padding-right: 15px;
    padding-left: 15px;
    font-size: 9px;
    text-transform: uppercase;
}
.popover {
    font-size: 12px;
    font-weight: 300;
    color: #fff;
}
.panel-heading, .panel-footer {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}
.clearfix:before, .clearfix:after {
    display: table;
    content: " "}
.clearfix:after {
    clear: both;
}
.clearfix:before, .clearfix:after {
    display: table;
    content: " "}
.clearfix:after {
    clear: both;
}
.center-block {
    display: block;
    margin-right: auto;
    margin-left: auto;
}
.pull-right {
    float: right!important;
}
.pull-left {
    float: left!important;
}
.hide {
    display: none!important;
}
.show {
    display: block!important;
}
.invisible {
    visibility: hidden;
}
.text-hide {
    font: 0/0 a;
    color: transparent;
    text-shadow: none;
    background-color: transparent;
    border: 0;
}
.hidden {
    display: none!important;
    visibility: hidden!important;
}
.affix {
    position: fixed;
}
